#if !defined(RTCTRADEAPISTRUCT_API_H)
#define RTCTRADEAPISTRUCT_API_H

#include "RTCUserApiDataType.h"
#include "RTCErrorCode.h"

///信息分发
struct ICEDisseminationField
{
	///序列系列号
	ICESequenceSeriesType	SequenceSeries;
	///序列号
	ICESequenceNoType	SequenceNo;
};

///用户登录请求
struct ICEReqUserLoginField
{
	///交易日
	ICEDateType	TradingDay;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///密码
	ICEPasswordType	Password;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///接口端产品信息
	ICEProductInfoType	InterfaceProductInfo;
	///协议信息
	ICEProtocolInfoType	ProtocolInfo;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///动态密码
	ICEPasswordType	OneTimePassword;
	///终端IP地址
	ICEIPAddressType	ClientIPAddress;
	///登录备注
	ICELoginRemarkType	LoginRemark;
};

///用户登录应答
struct ICERspUserLoginField
{
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///登录成功时间
	ICETimeType	LoginTime;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///交易系统名称
	ICESystemNameType	SystemName;
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///最大报单引用
	ICEOrderRefType	MaxOrderRef;//Unsupported
	///上期所时间
	ICETimeType	SHFETime;//Unsupported
	///大商所时间
	ICETimeType	DCETime;//Unsupported
	///郑商所时间
	ICETimeType	CZCETime;//Unsupported
	///中金所时间
	ICETimeType	FFEXTime;//Unsupported
	///能源中心时间
	ICETimeType	INETime;//Unsupported
};

///用户登出请求
struct ICEUserLogoutField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///强制交易员退出
struct ICEForceUserLogoutField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///客户端认证请求
struct ICEReqAuthenticateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///认证码
	ICEAuthCodeType	AuthCode;
};

///客户端认证响应
struct ICERspAuthenticateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
};

///客户端认证信息
struct ICEAuthenticationInfoField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///认证信息
	ICEAuthInfoType	AuthInfo;
	///是否为认证结果
	ICEBoolType	IsResult;
};

///银期转帐报文头
struct ICETransferHeaderField
{
	///版本号，常量，1.0
	ICEVersionType	Version;
	///交易代码，必填
	ICETradeCodeType	TradeCode;
	///交易日期，必填，格式：yyyymmdd
	ICETradeDateType	TradeDate;
	///交易时间，必填，格式：hhmmss
	ICETradeTimeType	TradeTime;
	///发起方流水号，N/A
	ICETradeSerialType	TradeSerial;
	///期货公司代码，必填
	ICEFutureIDType	FutureID;
	///银行代码，根据查询银行得到，必填
	ICEBankIDType	BankID;
	///银行分中心代码，根据查询银行得到，必填
	ICEBankBrchIDType	BankBrchID;
	///操作员，N/A
	ICEOperNoType	OperNo;
	///交易设备类型，N/A
	ICEDeviceIDType	DeviceID;
	///记录数，N/A
	ICERecordNumType	RecordNum;
	///会话编号，N/A
	ICESessionIDType	SessionID;
	///请求编号，N/A
	ICERequestIDType	RequestID;
};

///银行资金转期货请求，TradeCode=202001
struct ICETransferBankToFutureReqField
{
	///期货资金账户
	ICEAccountIDType	FutureAccount;
	///密码标志
	ICEFuturePwdFlagType	FuturePwdFlag;
	///密码
	ICEFutureAccPwdType	FutureAccPwd;
	///转账金额
	ICEMoneyType	TradeAmt;
	///客户手续费
	ICEMoneyType	CustFee;
	///币种：RMB-人民币 USD-美圆 HKD-港元
	ICECurrencyCodeType	CurrencyCode;
};

///银行资金转期货请求响应
struct ICETransferBankToFutureRspField
{
	///响应代码
	ICERetCodeType	RetCode;
	///响应信息
	ICERetInfoType	RetInfo;
	///资金账户
	ICEAccountIDType	FutureAccount;
	///转帐金额
	ICEMoneyType	TradeAmt;
	///应收客户手续费
	ICEMoneyType	CustFee;
	///币种
	ICECurrencyCodeType	CurrencyCode;
};

///期货资金转银行请求，TradeCode=202002
struct ICETransferFutureToBankReqField
{
	///期货资金账户
	ICEAccountIDType	FutureAccount;
	///密码标志
	ICEFuturePwdFlagType	FuturePwdFlag;
	///密码
	ICEFutureAccPwdType	FutureAccPwd;
	///转账金额
	ICEMoneyType	TradeAmt;
	///客户手续费
	ICEMoneyType	CustFee;
	///币种：RMB-人民币 USD-美圆 HKD-港元
	ICECurrencyCodeType	CurrencyCode;
};

///期货资金转银行请求响应
struct ICETransferFutureToBankRspField
{
	///响应代码
	ICERetCodeType	RetCode;
	///响应信息
	ICERetInfoType	RetInfo;
	///资金账户
	ICEAccountIDType	FutureAccount;
	///转帐金额
	ICEMoneyType	TradeAmt;
	///应收客户手续费
	ICEMoneyType	CustFee;
	///币种
	ICECurrencyCodeType	CurrencyCode;
};

///查询银行资金请求，TradeCode=204002
struct ICETransferQryBankReqField
{
	///期货资金账户
	ICEAccountIDType	FutureAccount;
	///密码标志
	ICEFuturePwdFlagType	FuturePwdFlag;
	///密码
	ICEFutureAccPwdType	FutureAccPwd;
	///币种：RMB-人民币 USD-美圆 HKD-港元
	ICECurrencyCodeType	CurrencyCode;
};

///查询银行资金请求响应
struct ICETransferQryBankRspField
{
	///响应代码
	ICERetCodeType	RetCode;
	///响应信息
	ICERetInfoType	RetInfo;
	///资金账户
	ICEAccountIDType	FutureAccount;
	///银行余额
	ICEMoneyType	TradeAmt;
	///银行可用余额
	ICEMoneyType	UseAmt;
	///银行可取余额
	ICEMoneyType	FetchAmt;
	///币种
	ICECurrencyCodeType	CurrencyCode;
};

///查询银行交易明细请求，TradeCode=204999
struct ICETransferQryDetailReqField
{
	///期货资金账户
	ICEAccountIDType	FutureAccount;
};

///查询银行交易明细请求响应
struct ICETransferQryDetailRspField
{
	///交易日期
	ICEDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///交易代码
	ICETradeCodeType	TradeCode;
	///期货流水号
	ICETradeSerialNoType	FutureSerial;
	///期货公司代码
	ICEFutureIDType	FutureID;
	///资金帐号
	ICEFutureAccountType	FutureAccount;
	///银行流水号
	ICETradeSerialNoType	BankSerial;
	///银行代码
	ICEBankIDType	BankID;
	///银行分中心代码
	ICEBankBrchIDType	BankBrchID;
	///银行账号
	ICEBankAccountType	BankAccount;
	///证件号码
	ICECertCodeType	CertCode;
	///货币代码
	ICECurrencyCodeType	CurrencyCode;
	///发生金额
	ICEMoneyType	TxAmount;
	///有效标志
	ICETransferValidFlagType	Flag;
};

///响应信息
struct ICERspInfoField
{
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///交易所
struct ICEExchangeField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所名称
	ICEExchangeNameType	ExchangeName;
	///交易所属性
	ICEExchangePropertyType	ExchangeProperty;
};

///产品
struct ICEProductField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
	///产品名称
	ICEProductNameType	ProductName;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///产品类型
	ICEProductClassType	ProductClass;
	///合约数量乘数
	ICEVolumeMultipleType	VolumeMultiple;
	///最小变动价位
	ICEPriceType	PriceTick;
	///市价单最大下单量
	ICEVolumeType	MaxMarketOrderVolume;
	///市价单最小下单量
	ICEVolumeType	MinMarketOrderVolume;
	///限价单最大下单量
	ICEVolumeType	MaxLimitOrderVolume;
	///限价单最小下单量
	ICEVolumeType	MinLimitOrderVolume;
	///持仓类型
	ICEPositionTypeType	PositionType;
	///持仓日期类型
	ICEPositionDateTypeType	PositionDateType;
	///平仓处理类型
	ICECloseDealTypeType	CloseDealType;
	///交易币种类型
	ICECurrencyIDType	TradeCurrencyID;
	///质押资金可用范围
	ICEMortgageFundUseRangeType	MortgageFundUseRange;
	///交易所产品代码
	ICEInstrumentIDType	ExchangeProductID;
	///合约基础商品乘数
	ICEUnderlyingMultipleType	UnderlyingMultiple;
};

///合约
struct ICEInstrumentField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约名称
	ICEInstrumentNameType	InstrumentName;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///产品代码
	ICEInstrumentIDType	ProductID;//Unsupported
	///产品类型
	ICEProductClassType	ProductClass;//Unsupported
	///交割年份
	ICEYearType	DeliveryYear;//Unsupported
	///交割月
	ICEMonthType	DeliveryMonth;//Unsupported
	///市价单最大下单量
	ICEVolumeType	MaxMarketOrderVolume;//Unsupported
	///市价单最小下单量
	ICEVolumeType	MinMarketOrderVolume;//Unsupported
	///限价单最大下单量
	ICEVolumeType	MaxLimitOrderVolume;//Unsupported
	///限价单最小下单量
	ICEVolumeType	MinLimitOrderVolume;//Unsupported
	///合约数量乘数
	ICEVolumeMultipleType	VolumeMultiple;
	///最小变动价位
	ICEPriceType	PriceTick;//Unsupported
	///创建日
	ICEDateType	CreateDate;//Unsupported
	///上市日
	ICEDateType	OpenDate;//Unsupported
	///到期日
	ICEDateType	ExpireDate;
	///开始交割日
	ICEDateType	StartDelivDate;//Unsupported
	///结束交割日
	ICEDateType	EndDelivDate;//Unsupported
	///合约生命周期状态
	ICEInstLifePhaseType	InstLifePhase;//Unsupported
	///当前是否交易
	ICEBoolType	IsTrading;//Unsupported
	///持仓类型
	ICEPositionTypeType	PositionType;//Unsupported
	///持仓日期类型
	ICEPositionDateTypeType	PositionDateType;//Unsupported
	///多头保证金率
	ICERatioType	LongMarginRatio;//Unsupported
	///空头保证金率
	ICERatioType	ShortMarginRatio;//Unsupported
	///是否使用大额单边保证金算法
	ICEMaxMarginSideAlgorithmType	MaxMarginSideAlgorithm;//Unsupported
	///基础商品代码
	ICEInstrumentIDType	UnderlyingInstrID;
	///执行价
	ICEPriceType	StrikePrice;
	///期权类型
	ICEOptionsTypeType	OptionsType;
	///合约基础商品乘数
	ICEUnderlyingMultipleType	UnderlyingMultiple;//Unsupported
	///组合类型
	ICECombinationTypeType	CombinationType;//Unsupported
	///最小买下单单位
	ICEVolumeType	MinBuyVolume;//Unsupported
	///最小卖下单单位
	ICEVolumeType	MinSellVolume;//Unsupported
	///合约标识码
	ICEInstrumentCodeType	InstrumentCode;
};

///经纪公司
struct ICEBrokerField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///经纪公司简称
	ICEBrokerAbbrType	BrokerAbbr;
	///经纪公司名称
	ICEBrokerNameType	BrokerName;
	///是否活跃
	ICEBoolType	IsActive;
};

///交易所交易员
struct ICETraderField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///密码
	ICEPasswordType	Password;
	///安装数量
	ICEInstallCountType	InstallCount;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///投资者
struct ICEInvestorField
{
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者分组代码
	ICEInvestorIDType	InvestorGroupID;//Unsupported
	///投资者名称
	ICEPartyNameType	InvestorName;
	///证件类型
	ICEIdCardTypeType	IdentifiedCardType;//Unsupported
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;//Unsupported
	///是否活跃
	ICEBoolType	IsActive;//Unsupported
	///联系电话
	ICETelephoneType	Telephone;//Unsupported
	///通讯地址
	ICEAddressType	Address;//Unsupported
	///开户日期
	ICEDateType	OpenDate;//Unsupported
	///手机
	ICEMobileType	Mobile;//Unsupported
	///手续费率模板代码
	ICEInvestorIDType	CommModelID;//Unsupported
	///保证金率模板代码
	ICEInvestorIDType	MarginModelID;//Unsupported
};

///交易编码
struct ICETradingCodeField
{
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///客户代码
	ICEClientIDType	ClientID;
	///是否活跃
	ICEBoolType	IsActive;
	///交易编码类型
	ICEClientIDTypeType	ClientIDType;
	///营业部编号
	ICEBranchIDType	BranchID;
	///业务类型
	ICEBizTypeType	BizType;
};

///会员编码和经纪公司编码对照表
struct ICEPartBrokerField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///是否活跃
	ICEBoolType	IsActive;
};

///管理用户
struct ICESuperUserField
{
	///用户代码
	ICEUserIDType	UserID;
	///用户名称
	ICEUserNameType	UserName;
	///密码
	ICEPasswordType	Password;
	///是否活跃
	ICEBoolType	IsActive;
};

///管理用户功能权限
struct ICESuperUserFunctionField
{
	///用户代码
	ICEUserIDType	UserID;
	///功能代码
	ICEFunctionCodeType	FunctionCode;
};

///投资者组
struct ICEInvestorGroupField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者分组代码
	ICEInvestorIDType	InvestorGroupID;
	///投资者分组名称
	ICEInvestorGroupNameType	InvestorGroupName;
};

///资金账户
struct ICETradingAccountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///上次质押金额
	ICEMoneyType	PreMortgage;
	///上次信用额度
	ICEMoneyType	PreCredit;
	///上次存款额
	ICEMoneyType	PreDeposit;
	///上次结算准备金
	ICEMoneyType	PreBalance;
	///上次占用的保证金
	ICEMoneyType	PreMargin;
	///利息基数
	ICEMoneyType	InterestBase;
	///利息收入
	ICEMoneyType	Interest;
	///入金金额
	ICEMoneyType	Deposit;
	///出金金额
	ICEMoneyType	Withdraw;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
	///冻结的资金
	ICEMoneyType	FrozenCash;
	///冻结的手续费
	ICEMoneyType	FrozenCommission;
	///当前保证金总额
	ICEMoneyType	CurrMargin;
	///资金差额
	ICEMoneyType	CashIn;
	///手续费
	ICEMoneyType	Commission;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///持仓盈亏
	ICEMoneyType	PositionProfit;
	///期货结算准备金
	ICEMoneyType	Balance;
	///可用资金
	ICEMoneyType	Available;
	///可取资金
	ICEMoneyType	WithdrawQuota;
	///基本准备金
	ICEMoneyType	Reserve;
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///信用额度
	ICEMoneyType	Credit;
	///质押金额
	ICEMoneyType	Mortgage;
	///交易所保证金
	ICEMoneyType	ExchangeMargin;
	///投资者交割保证金
	ICEMoneyType	DeliveryMargin;
	///交易所交割保证金
	ICEMoneyType	ExchangeDeliveryMargin;
	///保底期货结算准备金
	ICEMoneyType	ReserveBalance;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///上次货币质入金额
	ICEMoneyType	PreFundMortgageIn;
	///上次货币质出金额
	ICEMoneyType	PreFundMortgageOut;
	///货币质入金额
	ICEMoneyType	FundMortgageIn;
	///货币质出金额
	ICEMoneyType	FundMortgageOut;
	///货币质押余额
	ICEMoneyType	FundMortgageAvailable;
	///可质押货币金额
	ICEMoneyType	MortgageableFund;
	///特殊产品占用保证金
	ICEMoneyType	SpecProductMargin;
	///特殊产品冻结保证金
	ICEMoneyType	SpecProductFrozenMargin;
	///特殊产品手续费
	ICEMoneyType	SpecProductCommission;
	///特殊产品冻结手续费
	ICEMoneyType	SpecProductFrozenCommission;
	///特殊产品持仓盈亏
	ICEMoneyType	SpecProductPositionProfit;
	///特殊产品平仓盈亏
	ICEMoneyType	SpecProductCloseProfit;
	///根据持仓盈亏算法计算的特殊产品持仓盈亏
	ICEMoneyType	SpecProductPositionProfitByAlg;
	///特殊产品交易所保证金
	ICEMoneyType	SpecProductExchangeMargin;
	///业务类型
	ICEBizTypeType	BizType;//Unsupported
};

///投资者持仓
struct ICEInvestorPositionField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///持仓多空方向
	ICEPosiDirectionType	PosiDirection;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;//Unsupported
	///持仓日期
	ICEPositionDateType	PositionDate;//Unsupported
	///上日持仓
	ICEVolumeType	YdPosition;
	///今日持仓
	ICEVolumeType	Position;
	///多头冻结
	ICEVolumeType	LongFrozen;
	///空头冻结
	ICEVolumeType	ShortFrozen;
	///开仓冻结金额
	ICEMoneyType	LongFrozenAmount;
	///开仓冻结金额
	ICEMoneyType	ShortFrozenAmount;
	///开仓量
	ICEVolumeType	OpenVolume;
	///平仓量
	ICEVolumeType	CloseVolume;
	///开仓金额
	ICEMoneyType	OpenAmount;
	///平仓金额
	ICEMoneyType	CloseAmount;
	///持仓成本
	ICEMoneyType	PositionCost;
	///上次占用的保证金
	ICEMoneyType	PreMargin;
	///占用的保证金
	ICEMoneyType	UseMargin;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
	///冻结的资金
	ICEMoneyType	FrozenCash;
	///冻结的手续费
	ICEMoneyType	FrozenCommission;//Unsupported
	///资金差额
	ICEMoneyType	CashIn;
	///手续费
	ICEMoneyType	Commission;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///持仓盈亏
	ICEMoneyType	PositionProfit;//Unsupported
	///上次结算价
	ICEPriceType	PreSettlementPrice;
	///本次结算价
	ICEPriceType	SettlementPrice;
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///开仓成本
	ICEMoneyType	OpenCost;
	///交易所保证金
	ICEMoneyType	ExchangeMargin;//Unsupported
	///组合成交形成的持仓
	ICEVolumeType	CombPosition;
	///组合多头冻结
	ICEVolumeType	CombLongFrozen;
	///组合空头冻结
	ICEVolumeType	CombShortFrozen;
	///逐日盯市平仓盈亏
	ICEMoneyType	CloseProfitByDate;
	///逐笔对冲平仓盈亏
	ICEMoneyType	CloseProfitByTrade;
	///今日持仓
	ICEVolumeType	TodayPosition;
	///保证金率
	ICERatioType	MarginRateByMoney;
	///保证金率(按手数)
	ICERatioType	MarginRateByVolume;
	///执行冻结
	ICEVolumeType	StrikeFrozen;
	///执行冻结金额
	ICEMoneyType	StrikeFrozenAmount;
	///放弃执行冻结
	ICEVolumeType	AbandonFrozen;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行冻结的昨仓
	ICEVolumeType	YdStrikeFrozen;//Unsupported
};

///合约保证金率
struct ICEInstrumentMarginRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///多头保证金率
	ICERatioType	LongMarginRatioByMoney;
	///多头保证金费
	ICEMoneyType	LongMarginRatioByVolume;
	///空头保证金率
	ICERatioType	ShortMarginRatioByMoney;
	///空头保证金费
	ICEMoneyType	ShortMarginRatioByVolume;
	///是否相对交易所收取
	ICEBoolType	IsRelative;
};

///合约手续费率
struct ICEInstrumentCommissionRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///业务类型
	ICEBizTypeType	BizType;
};

///深度行情
struct ICEDepthMarketDataField
{
	///交易日
	ICEDateType	TradingDay;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///最新价
	ICEPriceType	LastPrice;
	///上次结算价
	ICEPriceType	PreSettlementPrice;
	///昨收盘
	ICEPriceType	PreClosePrice;
	///昨持仓量
	ICELargeVolumeType	PreOpenInterest;
	///今开盘
	ICEPriceType	OpenPrice;
	///最高价
	ICEPriceType	HighestPrice;
	///最低价
	ICEPriceType	LowestPrice;
	///数量
	ICEVolumeType	Volume;
	///成交金额
	ICEMoneyType	Turnover;
	///持仓量
	ICELargeVolumeType	OpenInterest;
	///今收盘
	ICEPriceType	ClosePrice;
	///本次结算价
	ICEPriceType	SettlementPrice;
	///涨停板价
	ICEPriceType	UpperLimitPrice;
	///跌停板价
	ICEPriceType	LowerLimitPrice;
	///昨虚实度
	ICERatioType	PreDelta;//Unsupported
	///今虚实度
	ICERatioType	CurrDelta;//Unsupported
	///最后修改时间
	ICETimeType	UpdateTime;
	///最后修改毫秒
	ICEMillisecType	UpdateMillisec;//Unsupported
	///申买价一
	ICEPriceType	BidPrice1;
	///申买量一
	ICEVolumeType	BidVolume1;
	///申卖价一
	ICEPriceType	AskPrice1;
	///申卖量一
	ICEVolumeType	AskVolume1;
	///申买价二
	ICEPriceType	BidPrice2;
	///申买量二
	ICEVolumeType	BidVolume2;
	///申卖价二
	ICEPriceType	AskPrice2;
	///申卖量二
	ICEVolumeType	AskVolume2;
	///申买价三
	ICEPriceType	BidPrice3;
	///申买量三
	ICEVolumeType	BidVolume3;
	///申卖价三
	ICEPriceType	AskPrice3;
	///申卖量三
	ICEVolumeType	AskVolume3;
	///申买价四
	ICEPriceType	BidPrice4;
	///申买量四
	ICEVolumeType	BidVolume4;
	///申卖价四
	ICEPriceType	AskPrice4;
	///申卖量四
	ICEVolumeType	AskVolume4;
	///申买价五
	ICEPriceType	BidPrice5;
	///申买量五
	ICEVolumeType	BidVolume5;
	///申卖价五
	ICEPriceType	AskPrice5;
	///申卖量五
	ICEVolumeType	AskVolume5;
	///当日均价
	ICEPriceType	AveragePrice;//Unsupported
	///业务日期
	ICEDateType	ActionDay;//Unsupported
	///合约交易状态
	ICEInstrumentStatusType	InstrumentStatus;
};

///投资者合约交易权限
struct ICEInstrumentTradingRightField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易权限
	ICETradingRightType	TradingRight;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///业务类型
	ICEBizTypeType	BizType;
};

///经纪公司用户
struct ICEBrokerUserField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户名称
	ICEUserNameType	UserName;
	///用户类型
	ICEUserTypeType	UserType;
	///是否活跃
	ICEBoolType	IsActive;
	///是否使用令牌
	ICEBoolType	IsUsingOTP;
};

///经纪公司用户口令
struct ICEBrokerUserPasswordField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///密码
	ICEPasswordType	Password;
};

///经纪公司用户功能权限
struct ICEBrokerUserFunctionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///经纪公司功能代码
	ICEBrokerFunctionCodeType	BrokerFunctionCode;
};

///交易所交易员报盘机
struct ICETraderOfferField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///交易所交易员连接状态
	ICETraderConnectStatusType	TraderConnectStatus;
	///发出连接请求的日期
	ICEDateType	ConnectRequestDate;
	///发出连接请求的时间
	ICETimeType	ConnectRequestTime;
	///上次报告日期
	ICEDateType	LastReportDate;
	///上次报告时间
	ICETimeType	LastReportTime;
	///完成连接日期
	ICEDateType	ConnectDate;
	///完成连接时间
	ICETimeType	ConnectTime;
	///启动日期
	ICEDateType	StartDate;
	///启动时间
	ICETimeType	StartTime;
	///交易日
	ICEDateType	TradingDay;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///本席位最大成交编号
	ICETradeIDType	MaxTradeID;
	///本席位最大报单备拷
	ICEReturnCodeType	MaxOrderMessageReference;
	///业务类型
	ICEBizTypeType	BizType;
};

///投资者结算结果
struct ICESettlementInfoField
{
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///序号
	ICESequenceNoType	SequenceNo;//Unsupported
	///消息正文
	ICEContentType	Content;
};

///合约保证金率调整
struct ICEInstrumentMarginRateAdjustField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///多头保证金率
	ICERatioType	LongMarginRatioByMoney;
	///多头保证金费
	ICEMoneyType	LongMarginRatioByVolume;
	///空头保证金率
	ICERatioType	ShortMarginRatioByMoney;
	///空头保证金费
	ICEMoneyType	ShortMarginRatioByVolume;
	///是否相对交易所收取
	ICEBoolType	IsRelative;
};

///交易所保证金率
struct ICEExchangeMarginRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///多头保证金率
	ICERatioType	LongMarginRatioByMoney;
	///多头保证金费
	ICEMoneyType	LongMarginRatioByVolume;
	///空头保证金率
	ICERatioType	ShortMarginRatioByMoney;
	///空头保证金费
	ICEMoneyType	ShortMarginRatioByVolume;
};

///交易所保证金率调整
struct ICEExchangeMarginRateAdjustField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///跟随交易所投资者多头保证金率
	ICERatioType	LongMarginRatioByMoney;
	///跟随交易所投资者多头保证金费
	ICEMoneyType	LongMarginRatioByVolume;
	///跟随交易所投资者空头保证金率
	ICERatioType	ShortMarginRatioByMoney;
	///跟随交易所投资者空头保证金费
	ICEMoneyType	ShortMarginRatioByVolume;
	///交易所多头保证金率
	ICERatioType	ExchLongMarginRatioByMoney;
	///交易所多头保证金费
	ICEMoneyType	ExchLongMarginRatioByVolume;
	///交易所空头保证金率
	ICERatioType	ExchShortMarginRatioByMoney;
	///交易所空头保证金费
	ICEMoneyType	ExchShortMarginRatioByVolume;
	///不跟随交易所投资者多头保证金率
	ICERatioType	NoLongMarginRatioByMoney;
	///不跟随交易所投资者多头保证金费
	ICEMoneyType	NoLongMarginRatioByVolume;
	///不跟随交易所投资者空头保证金率
	ICERatioType	NoShortMarginRatioByMoney;
	///不跟随交易所投资者空头保证金费
	ICEMoneyType	NoShortMarginRatioByVolume;
};

///汇率
struct ICEExchangeRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///源币种
	ICECurrencyIDType	FromCurrencyID;
	///源币种单位数量
	ICECurrencyUnitType	FromCurrencyUnit;
	///目标币种
	ICECurrencyIDType	ToCurrencyID;
	///汇率
	ICEExchangeRateType	ExchangeRate;
};

///结算引用
struct ICESettlementRefField
{
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
};

///当前时间
struct ICECurrentTimeField
{
	///当前日期
	ICEDateType	CurrDate;
	///当前时间
	ICETimeType	CurrTime;
	///当前时间（毫秒）
	ICEMillisecType	CurrMillisec;
	///业务日期
	ICEDateType	ActionDay;
};

///通讯阶段
struct ICECommPhaseField
{
	///交易日
	ICEDateType	TradingDay;
	///通讯时段编号
	ICECommPhaseNoType	CommPhaseNo;
	///系统编号
	ICESystemIDType	SystemID;
};

///登录信息
struct ICELoginInfoField
{
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///登录日期
	ICEDateType	LoginDate;
	///登录时间
	ICETimeType	LoginTime;
	///IP地址
	ICEIPAddressType	IPAddress;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///接口端产品信息
	ICEProductInfoType	InterfaceProductInfo;
	///协议信息
	ICEProtocolInfoType	ProtocolInfo;
	///系统名称
	ICESystemNameType	SystemName;
	///密码
	ICEPasswordType	Password;
	///最大报单引用
	ICEOrderRefType	MaxOrderRef;
	///上期所时间
	ICETimeType	SHFETime;
	///大商所时间
	ICETimeType	DCETime;
	///郑商所时间
	ICETimeType	CZCETime;
	///中金所时间
	ICETimeType	FFEXTime;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///动态密码
	ICEPasswordType	OneTimePassword;
	///能源中心时间
	ICETimeType	INETime;
	///登录备注
	ICELoginRemarkType	LoginRemark;
};

///登录信息
struct ICELogoutAllField
{
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///系统名称
	ICESystemNameType	SystemName;
};

///前置状态
struct ICEFrontStatusField
{
	///前置编号
	ICEFrontIDType	FrontID;
	///上次报告日期
	ICEDateType	LastReportDate;
	///上次报告时间
	ICETimeType	LastReportTime;
	///是否活跃
	ICEBoolType	IsActive;
};

///用户口令变更
struct ICEUserPasswordUpdateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///原来的口令
	ICEPasswordType	OldPassword;
	///新的口令
	ICEPasswordType	NewPassword;
};

///输入报单
struct ICEInputOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;//Unsupported
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;//Unsupported
	///触发条件
	ICEContingentConditionType	ContingentCondition;//Unsupported
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;//Unsupported
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///用户强评标志
	ICEBoolType	UserForceClose;//Unsupported
	///互换单标志
	ICEBoolType	IsSwapOrder;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///资金账号
	ICEAccountIDType	AccountID;//Unsupported
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
	///交易编码
	ICEClientIDType	ClientID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
	///自適應
	ICEBoolType			IsFitOrderFreq;
};

///报单
struct ICEOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;//Unsupported
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;//Unsupported
	///触发条件
	ICEContingentConditionType	ContingentCondition;//Unsupported
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;//Unsupported
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;//Unsupported
	///客户代码
	ICEClientIDType	ClientID;//Unsupported
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;//Unsupported
	///安装编号
	ICEInstallIDType	InstallID;//Unsupported
	///报单提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;//Unsupported
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///报单来源
	ICEOrderSourceType	OrderSource;//Unsupported
	///报单状态
	ICEOrderStatusType	OrderStatus;
	///报单类型
	ICEOrderTypeType	OrderType;//Unsupported
	///今成交数量
	ICEVolumeType	VolumeTraded;
	///剩余数量
	ICEVolumeType	VolumeTotal;
	///报单日期
	ICEDateType	InsertDate;
	///委托时间
	ICETimeType	InsertTime;
	///激活时间
	ICETimeType	ActiveTime;//Unsupported
	///挂起时间
	ICETimeType	SuspendTime;//Unsupported
	///最后修改时间
	ICETimeType	UpdateTime;//Unsupported
	///撤销时间
	ICETimeType	CancelTime;//Unsupported
	///最后修改交易所交易员代码
	ICETraderIDType	ActiveTraderID;//Unsupported
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;//Unsupported
	///序号
	ICESequenceNoType	SequenceNo;//Unsupported
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;//Unsupported
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///用户强评标志
	ICEBoolType	UserForceClose;//Unsupported
	///操作用户代码
	ICEUserIDType	ActiveUserID;//Unsupported
	///经纪公司报单编号
	ICESequenceNoType	BrokerOrderSeq;//Unsupported
	///相关报单
	ICEOrderSysIDType	RelativeOrderSysID;//Unsupported
	///郑商所成交数量
	ICEVolumeType	ZCETotalTradedVolume;//Unsupported
	///互换单标志
	ICEBoolType	IsSwapOrder;//Unsupported
	///营业部编号
	ICEBranchIDType	BranchID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///资金账号
	ICEAccountIDType	AccountID;//Unsupported
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
	///TCore 报单编号
	ICEOrderSysIDType	ReportID;
};

///交易所报单
struct ICEExchangeOrderField
{
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;
	///触发条件
	ICEContingentConditionType	ContingentCondition;
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///请求编号
	ICERequestIDType	RequestID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报单提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///报单来源
	ICEOrderSourceType	OrderSource;
	///报单状态
	ICEOrderStatusType	OrderStatus;
	///报单类型
	ICEOrderTypeType	OrderType;
	///今成交数量
	ICEVolumeType	VolumeTraded;
	///剩余数量
	ICEVolumeType	VolumeTotal;
	///报单日期
	ICEDateType	InsertDate;
	///委托时间
	ICETimeType	InsertTime;
	///激活时间
	ICETimeType	ActiveTime;
	///挂起时间
	ICETimeType	SuspendTime;
	///最后修改时间
	ICETimeType	UpdateTime;
	///撤销时间
	ICETimeType	CancelTime;
	///最后修改交易所交易员代码
	ICETraderIDType	ActiveTraderID;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所报单插入失败
struct ICEExchangeOrderInsertErrorField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///输入报单操作
struct ICEInputOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;//Unsupported
	///投资者代码
	ICEInvestorIDType	InvestorID;//Unsupported
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;//Unsupported
	///报单引用
	ICEOrderRefType	OrderRef;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///报单编号
	ICEOrderSysIDType	OrderSysID;//Unsupported
	///操作标志
	ICEActionFlagType	ActionFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量变化
	ICEVolumeType	VolumeChange;
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///合约代码
	ICEInstrumentIDType	InstrumentID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
	///TCore 报单编号
	ICEOrderSysIDType	ReportID;
};

///报单操作
struct ICEOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;
	///报单引用
	ICEOrderRefType	OrderRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量变化
	ICEVolumeType	VolumeChange;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所报单操作
struct ICEExchangeOrderActionField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量变化
	ICEVolumeType	VolumeChange;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所报单操作失败
struct ICEExchangeOrderActionErrorField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///交易所成交
struct ICEExchangeTradeField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///成交编号
	ICETradeIDType	TradeID;
	///买卖方向
	ICEDirectionType	Direction;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易角色
	ICETradingRoleType	TradingRole;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///价格
	ICEPriceType	Price;
	///数量
	ICEVolumeType	Volume;
	///成交时期
	ICEDateType	TradeDate;
	///成交时间
	ICETimeType	TradeTime;
	///成交类型
	ICETradeTypeType	TradeType;
	///成交价来源
	ICEPriceSourceType	PriceSource;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///序号
	ICESequenceNoType	SequenceNo;
	///成交来源
	ICETradeSourceType	TradeSource;
};

///成交
struct ICETradeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///成交编号
	ICETradeIDType	TradeID;
	///买卖方向
	ICEDirectionType	Direction;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///会员代码
	ICEParticipantIDType	ParticipantID;//Unsupported
	///客户代码
	ICEClientIDType	ClientID;//Unsupported
	///交易角色
	ICETradingRoleType	TradingRole;//Unsupported
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;//Unsupported
	///价格
	ICEPriceType	Price;
	///数量
	ICEVolumeType	Volume;
	///成交时期
	ICEDateType	TradeDate;
	///成交时间
	ICETimeType	TradeTime;
	///成交类型
	ICETradeTypeType	TradeType;//Unsupported
	///成交价来源
	ICEPriceSourceType	PriceSource;//Unsupported
	///交易所交易员代码
	ICETraderIDType	TraderID;//Unsupported
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;//Unsupported
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///序号
	ICESequenceNoType	SequenceNo;//Unsupported
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///经纪公司报单编号
	ICESequenceNoType	BrokerOrderSeq;//Unsupported
	///成交来源
	ICETradeSourceType	TradeSource;//Unsupported
	///TCore 报单编号
	ICEOrderSysIDType	ReportID;
};

///用户会话
struct ICEUserSessionField
{
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///登录日期
	ICEDateType	LoginDate;
	///登录时间
	ICETimeType	LoginTime;
	///IP地址
	ICEIPAddressType	IPAddress;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///接口端产品信息
	ICEProductInfoType	InterfaceProductInfo;
	///协议信息
	ICEProtocolInfoType	ProtocolInfo;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///登录备注
	ICELoginRemarkType	LoginRemark;
};

///查询最大报单数量
struct ICEQueryMaxOrderVolumeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///买卖方向
	ICEDirectionType	Direction;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///最大允许报单数量
	ICEVolumeType	MaxVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者结算结果确认信息
struct ICESettlementInfoConfirmField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///确认日期
	ICEDateType	ConfirmDate;//Unsupported
	///确认时间
	ICETimeType	ConfirmTime;//Unsupported
};

///出入金同步
struct ICESyncDepositField
{
	///出入金流水号
	ICEDepositSeqNoType	DepositSeqNo;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///入金金额
	ICEMoneyType	Deposit;
	///是否强制进行
	ICEBoolType	IsForce;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///业务类型
	ICEBizTypeType	BizType;
};

///货币质押同步
struct ICESyncFundMortgageField
{
	///货币质押流水号
	ICEDepositSeqNoType	MortgageSeqNo;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///源币种
	ICECurrencyIDType	FromCurrencyID;
	///质押金额
	ICEMoneyType	MortgageAmount;
	///目标币种
	ICECurrencyIDType	ToCurrencyID;
};

///经纪公司同步
struct ICEBrokerSyncField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///正在同步中的投资者
struct ICESyncingInvestorField
{
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者分组代码
	ICEInvestorIDType	InvestorGroupID;
	///投资者名称
	ICEPartyNameType	InvestorName;
	///证件类型
	ICEIdCardTypeType	IdentifiedCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///是否活跃
	ICEBoolType	IsActive;
	///联系电话
	ICETelephoneType	Telephone;
	///通讯地址
	ICEAddressType	Address;
	///开户日期
	ICEDateType	OpenDate;
	///手机
	ICEMobileType	Mobile;
	///手续费率模板代码
	ICEInvestorIDType	CommModelID;
	///保证金率模板代码
	ICEInvestorIDType	MarginModelID;
};

///正在同步中的交易代码
struct ICESyncingTradingCodeField
{
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///客户代码
	ICEClientIDType	ClientID;
	///是否活跃
	ICEBoolType	IsActive;
	///交易编码类型
	ICEClientIDTypeType	ClientIDType;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///正在同步中的投资者分组
struct ICESyncingInvestorGroupField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者分组代码
	ICEInvestorIDType	InvestorGroupID;
	///投资者分组名称
	ICEInvestorGroupNameType	InvestorGroupName;
};

///正在同步中的交易账号
struct ICESyncingTradingAccountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///上次质押金额
	ICEMoneyType	PreMortgage;
	///上次信用额度
	ICEMoneyType	PreCredit;
	///上次存款额
	ICEMoneyType	PreDeposit;
	///上次结算准备金
	ICEMoneyType	PreBalance;
	///上次占用的保证金
	ICEMoneyType	PreMargin;
	///利息基数
	ICEMoneyType	InterestBase;
	///利息收入
	ICEMoneyType	Interest;
	///入金金额
	ICEMoneyType	Deposit;
	///出金金额
	ICEMoneyType	Withdraw;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
	///冻结的资金
	ICEMoneyType	FrozenCash;
	///冻结的手续费
	ICEMoneyType	FrozenCommission;
	///当前保证金总额
	ICEMoneyType	CurrMargin;
	///资金差额
	ICEMoneyType	CashIn;
	///手续费
	ICEMoneyType	Commission;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///持仓盈亏
	ICEMoneyType	PositionProfit;
	///期货结算准备金
	ICEMoneyType	Balance;
	///可用资金
	ICEMoneyType	Available;
	///可取资金
	ICEMoneyType	WithdrawQuota;
	///基本准备金
	ICEMoneyType	Reserve;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///信用额度
	ICEMoneyType	Credit;
	///质押金额
	ICEMoneyType	Mortgage;
	///交易所保证金
	ICEMoneyType	ExchangeMargin;
	///投资者交割保证金
	ICEMoneyType	DeliveryMargin;
	///交易所交割保证金
	ICEMoneyType	ExchangeDeliveryMargin;
	///保底期货结算准备金
	ICEMoneyType	ReserveBalance;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///上次货币质入金额
	ICEMoneyType	PreFundMortgageIn;
	///上次货币质出金额
	ICEMoneyType	PreFundMortgageOut;
	///货币质入金额
	ICEMoneyType	FundMortgageIn;
	///货币质出金额
	ICEMoneyType	FundMortgageOut;
	///货币质押余额
	ICEMoneyType	FundMortgageAvailable;
	///可质押货币金额
	ICEMoneyType	MortgageableFund;
	///特殊产品占用保证金
	ICEMoneyType	SpecProductMargin;
	///特殊产品冻结保证金
	ICEMoneyType	SpecProductFrozenMargin;
	///特殊产品手续费
	ICEMoneyType	SpecProductCommission;
	///特殊产品冻结手续费
	ICEMoneyType	SpecProductFrozenCommission;
	///特殊产品持仓盈亏
	ICEMoneyType	SpecProductPositionProfit;
	///特殊产品平仓盈亏
	ICEMoneyType	SpecProductCloseProfit;
	///根据持仓盈亏算法计算的特殊产品持仓盈亏
	ICEMoneyType	SpecProductPositionProfitByAlg;
	///特殊产品交易所保证金
	ICEMoneyType	SpecProductExchangeMargin;
};

///正在同步中的投资者持仓
struct ICESyncingInvestorPositionField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///持仓多空方向
	ICEPosiDirectionType	PosiDirection;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///持仓日期
	ICEPositionDateType	PositionDate;
	///上日持仓
	ICEVolumeType	YdPosition;
	///今日持仓
	ICEVolumeType	Position;
	///多头冻结
	ICEVolumeType	LongFrozen;
	///空头冻结
	ICEVolumeType	ShortFrozen;
	///开仓冻结金额
	ICEMoneyType	LongFrozenAmount;
	///开仓冻结金额
	ICEMoneyType	ShortFrozenAmount;
	///开仓量
	ICEVolumeType	OpenVolume;
	///平仓量
	ICEVolumeType	CloseVolume;
	///开仓金额
	ICEMoneyType	OpenAmount;
	///平仓金额
	ICEMoneyType	CloseAmount;
	///持仓成本
	ICEMoneyType	PositionCost;
	///上次占用的保证金
	ICEMoneyType	PreMargin;
	///占用的保证金
	ICEMoneyType	UseMargin;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
	///冻结的资金
	ICEMoneyType	FrozenCash;
	///冻结的手续费
	ICEMoneyType	FrozenCommission;
	///资金差额
	ICEMoneyType	CashIn;
	///手续费
	ICEMoneyType	Commission;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///持仓盈亏
	ICEMoneyType	PositionProfit;
	///上次结算价
	ICEPriceType	PreSettlementPrice;
	///本次结算价
	ICEPriceType	SettlementPrice;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///开仓成本
	ICEMoneyType	OpenCost;
	///交易所保证金
	ICEMoneyType	ExchangeMargin;
	///组合成交形成的持仓
	ICEVolumeType	CombPosition;
	///组合多头冻结
	ICEVolumeType	CombLongFrozen;
	///组合空头冻结
	ICEVolumeType	CombShortFrozen;
	///逐日盯市平仓盈亏
	ICEMoneyType	CloseProfitByDate;
	///逐笔对冲平仓盈亏
	ICEMoneyType	CloseProfitByTrade;
	///今日持仓
	ICEVolumeType	TodayPosition;
	///保证金率
	ICERatioType	MarginRateByMoney;
	///保证金率(按手数)
	ICERatioType	MarginRateByVolume;
	///执行冻结
	ICEVolumeType	StrikeFrozen;
	///执行冻结金额
	ICEMoneyType	StrikeFrozenAmount;
	///放弃执行冻结
	ICEVolumeType	AbandonFrozen;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行冻结的昨仓
	ICEVolumeType	YdStrikeFrozen;
};

///正在同步中的合约保证金率
struct ICESyncingInstrumentMarginRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///多头保证金率
	ICERatioType	LongMarginRatioByMoney;
	///多头保证金费
	ICEMoneyType	LongMarginRatioByVolume;
	///空头保证金率
	ICERatioType	ShortMarginRatioByMoney;
	///空头保证金费
	ICEMoneyType	ShortMarginRatioByVolume;
	///是否相对交易所收取
	ICEBoolType	IsRelative;
};

///正在同步中的合约手续费率
struct ICESyncingInstrumentCommissionRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///正在同步中的合约交易权限
struct ICESyncingInstrumentTradingRightField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易权限
	ICETradingRightType	TradingRight;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询报单
struct ICEQryOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///开始时间
	ICETimeType	InsertTimeStart;//Unsupported
	///结束时间
	ICETimeType	InsertTimeEnd;//Unsupported
};

///查询成交
struct ICEQryTradeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///成交编号
	ICETradeIDType	TradeID;//Unsupported
	///开始时间
	ICETimeType	TradeTimeStart;//Unsupported
	///结束时间
	ICETimeType	TradeTimeEnd;//Unsupported
};

///查询投资者持仓
struct ICEQryInvestorPositionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询资金账户
struct ICEQryTradingAccountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///业务类型
	ICEBizTypeType	BizType;//Unsupported
};

///查询投资者
struct ICEQryInvestorField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///查询交易编码
struct ICEQryTradingCodeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易编码类型
	ICEClientIDTypeType	ClientIDType;
};

///查询投资者组
struct ICEQryInvestorGroupField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///查询合约保证金率
struct ICEQryInstrumentMarginRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///查询手续费率
struct ICEQryInstrumentCommissionRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询合约交易权限
struct ICEQryInstrumentTradingRightField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询经纪公司
struct ICEQryBrokerField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///查询交易员
struct ICEQryTraderField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询管理用户功能权限
struct ICEQrySuperUserFunctionField
{
	///用户代码
	ICEUserIDType	UserID;
};

///查询用户会话
struct ICEQryUserSessionField
{
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///查询经纪公司会员代码
struct ICEQryPartBrokerField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
};

///查询前置状态
struct ICEQryFrontStatusField
{
	///前置编号
	ICEFrontIDType	FrontID;
};

///查询交易所报单
struct ICEQryExchangeOrderField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询报单操作
struct ICEQryOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询交易所报单操作
struct ICEQryExchangeOrderActionField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询管理用户
struct ICEQrySuperUserField
{
	///用户代码
	ICEUserIDType	UserID;
};

///查询交易所
struct ICEQryExchangeField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询产品
struct ICEQryProductField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
	///产品类型
	ICEProductClassType	ProductClass;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询合约
struct ICEQryInstrumentField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///产品代码
	ICEInstrumentIDType	ProductID;//Unsupported
};

///查询行情
struct ICEQryDepthMarketDataField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询经纪公司用户
struct ICEQryBrokerUserField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///查询经纪公司用户权限
struct ICEQryBrokerUserFunctionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///查询交易员报盘机
struct ICEQryTraderOfferField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询出入金流水
struct ICEQrySyncDepositField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///出入金流水号
	ICEDepositSeqNoType	DepositSeqNo;
};

///查询投资者结算结果
struct ICEQrySettlementInfoField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易日
	ICEDateType	TradingDay;
};

///查询交易所保证金率
struct ICEQryExchangeMarginRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///查询交易所调整保证金率
struct ICEQryExchangeMarginRateAdjustField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///查询汇率
struct ICEQryExchangeRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///源币种
	ICECurrencyIDType	FromCurrencyID;
	///目标币种
	ICECurrencyIDType	ToCurrencyID;
};

///查询货币质押流水
struct ICEQrySyncFundMortgageField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///货币质押流水号
	ICEDepositSeqNoType	MortgageSeqNo;
};

///查询报单
struct ICEQryHisOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///开始时间
	ICETimeType	InsertTimeStart;
	///结束时间
	ICETimeType	InsertTimeEnd;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
};

///当前期权合约最小保证金
struct ICEOptionInstrMiniMarginField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///单位（手）期权合约最小保证金
	ICEMoneyType	MinMargin;
	///取值方式
	ICEValueMethodType	ValueMethod;
	///是否跟随交易所收取
	ICEBoolType	IsRelative;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///当前期权合约保证金调整系数
struct ICEOptionInstrMarginAdjustField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机空头保证金调整系数
	ICERatioType	SShortMarginRatioByMoney;
	///投机空头保证金调整系数
	ICEMoneyType	SShortMarginRatioByVolume;
	///保值空头保证金调整系数
	ICERatioType	HShortMarginRatioByMoney;
	///保值空头保证金调整系数
	ICEMoneyType	HShortMarginRatioByVolume;
	///套利空头保证金调整系数
	ICERatioType	AShortMarginRatioByMoney;
	///套利空头保证金调整系数
	ICEMoneyType	AShortMarginRatioByVolume;
	///是否跟随交易所收取
	ICEBoolType	IsRelative;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///做市商空头保证金调整系数
	ICERatioType	MShortMarginRatioByMoney;
	///做市商空头保证金调整系数
	ICEMoneyType	MShortMarginRatioByVolume;
};

///当前期权合约手续费的详细内容
struct ICEOptionInstrCommRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///执行手续费率
	ICERatioType	StrikeRatioByMoney;
	///执行手续费
	ICERatioType	StrikeRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///期权交易成本
struct ICEOptionInstrTradeCostField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///期权合约保证金不变部分
	ICEMoneyType	FixedMargin;
	///期权合约最小保证金
	ICEMoneyType	MiniMargin;
	///期权合约权利金
	ICEMoneyType	Royalty;
	///交易所期权合约保证金不变部分
	ICEMoneyType	ExchFixedMargin;
	///交易所期权合约最小保证金
	ICEMoneyType	ExchMiniMargin;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///期权交易成本查询
struct ICEQryOptionInstrTradeCostField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///期权合约报价
	ICEPriceType	InputPrice;
	///标的价格,填0则用昨结算价
	ICEPriceType	UnderlyingPrice;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///期权手续费率查询
struct ICEQryOptionInstrCommRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///股指现货指数
struct ICEIndexPriceField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///指数现货收盘价
	ICEPriceType	ClosePrice;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///输入的执行宣告
struct ICEInputExecOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;//Unsupported
	///执行类型
	ICEActionTypeType	ActionType;
	///保留头寸申请的持仓方向
	ICEPosiDirectionType	PosiDirection;//Unsupported
	///期权行权后是否保留期货头寸的标记
	ICEExecOrderPositionFlagType	ReservePositionFlag;//Unsupported
	///期权行权后生成的头寸是否自动平仓
	ICEExecOrderCloseFlagType	CloseFlag;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///资金账号
	ICEAccountIDType	AccountID;//Unsupported
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
	///交易编码
	ICEClientIDType	ClientID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///输入执行宣告操作
struct ICEInputExecOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///执行宣告操作引用
	ICEOrderActionRefType	ExecOrderActionRef;//Unsupported
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///执行宣告操作编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///执行宣告
struct ICEExecOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;//Unsupported
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///开平标志
	ICEOffsetFlagType	OffsetFlag;//Unsupported
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///执行类型
	ICEActionTypeType	ActionType;
	///保留头寸申请的持仓方向
	ICEPosiDirectionType	PosiDirection;
	///期权行权后是否保留期货头寸的标记
	ICEExecOrderPositionFlagType	ReservePositionFlag;
	///期权行权后生成的头寸是否自动平仓
	ICEExecOrderCloseFlagType	CloseFlag;
	///本地执行宣告编号
	ICEOrderLocalIDType	ExecOrderLocalID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;//Unsupported
	///客户代码
	ICEClientIDType	ClientID;//Unsupported
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;//Unsupported
	///交易所交易员代码
	ICETraderIDType	TraderID;//Unsupported
	///安装编号
	ICEInstallIDType	InstallID;//Unsupported
	///执行宣告提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;//Unsupported
	///报单提示序号
	ICESequenceNoType	NotifySequence;//Unsupported
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///执行宣告编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;
	///执行结果
	ICEExecResultType	ExecResult;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;//Unsupported
	///序号
	ICESequenceNoType	SequenceNo;//Unsupported
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;//Unsupported
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///操作用户代码
	ICEUserIDType	ActiveUserID;//Unsupported
	///经纪公司报单编号
	ICESequenceNoType	BrokerExecOrderSeq;//Unsupported
	///营业部编号
	ICEBranchIDType	BranchID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///执行宣告操作
struct ICEExecOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///执行宣告操作引用
	ICEOrderActionRefType	ExecOrderActionRef;
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行宣告操作编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地执行宣告编号
	ICEOrderLocalIDType	ExecOrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///执行类型
	ICEActionTypeType	ActionType;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///执行宣告查询
struct ICEQryExecOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行宣告编号
	ICEExecOrderSysIDType	ExecOrderSysID;//Unsupported
	///开始时间
	ICETimeType	InsertTimeStart;//Unsupported
	///结束时间
	ICETimeType	InsertTimeEnd;//Unsupported
};

///交易所执行宣告信息
struct ICEExchangeExecOrderField
{
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///执行类型
	ICEActionTypeType	ActionType;
	///保留头寸申请的持仓方向
	ICEPosiDirectionType	PosiDirection;
	///期权行权后是否保留期货头寸的标记
	ICEExecOrderPositionFlagType	ReservePositionFlag;
	///期权行权后生成的头寸是否自动平仓
	ICEExecOrderCloseFlagType	CloseFlag;
	///本地执行宣告编号
	ICEOrderLocalIDType	ExecOrderLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///执行宣告提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///执行宣告编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;
	///执行结果
	ICEExecResultType	ExecResult;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所执行宣告查询
struct ICEQryExchangeExecOrderField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///执行宣告操作查询
struct ICEQryExecOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所执行宣告操作
struct ICEExchangeExecOrderActionField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行宣告操作编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地执行宣告编号
	ICEOrderLocalIDType	ExecOrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///执行类型
	ICEActionTypeType	ActionType;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所执行宣告操作查询
struct ICEQryExchangeExecOrderActionField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///错误执行宣告
struct ICEErrExecOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///执行类型
	ICEActionTypeType	ActionType;
	///保留头寸申请的持仓方向
	ICEPosiDirectionType	PosiDirection;
	///期权行权后是否保留期货头寸的标记
	ICEExecOrderPositionFlagType	ReservePositionFlag;
	///期权行权后生成的头寸是否自动平仓
	ICEExecOrderCloseFlagType	CloseFlag;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///交易编码
	ICEClientIDType	ClientID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询错误执行宣告
struct ICEQryErrExecOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///错误执行宣告操作
struct ICEErrExecOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///执行宣告操作引用
	ICEOrderActionRefType	ExecOrderActionRef;
	///执行宣告引用
	ICEOrderRefType	ExecOrderRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行宣告操作编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询错误执行宣告操作
struct ICEQryErrExecOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///投资者期权合约交易权限
struct ICEOptionInstrTradingRightField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///买卖方向
	ICEDirectionType	Direction;
	///交易权限
	ICETradingRightType	TradingRight;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///查询期权合约交易权限
struct ICEQryOptionInstrTradingRightField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///买卖方向
	ICEDirectionType	Direction;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///输入的询价
struct ICEInputForQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///询价引用
	ICEOrderRefType	ForQuoteRef;//Unsupported
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///询价
struct ICEForQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///询价引用
	ICEOrderRefType	ForQuoteRef;
	///用户代码
	ICEUserIDType	UserID;
	///本地询价编号
	ICEOrderLocalIDType	ForQuoteLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///询价状态
	ICEForQuoteStatusType	ForQuoteStatus;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///操作用户代码
	ICEUserIDType	ActiveUserID;
	///经纪公司询价编号
	ICESequenceNoType	BrokerForQutoSeq;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///询价查询
struct ICEQryForQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///开始时间
	ICETimeType	InsertTimeStart;
	///结束时间
	ICETimeType	InsertTimeEnd;
};

///交易所询价信息
struct ICEExchangeForQuoteField
{
	///本地询价编号
	ICEOrderLocalIDType	ForQuoteLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///询价状态
	ICEForQuoteStatusType	ForQuoteStatus;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///交易所询价查询
struct ICEQryExchangeForQuoteField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///输入的报价
struct ICEInputQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报价引用
	ICEOrderRefType	QuoteRef;
	///用户代码
	ICEUserIDType	UserID;
	///卖价格
	ICEPriceType	AskPrice;
	///买价格
	ICEPriceType	BidPrice;
	///卖数量
	ICEVolumeType	AskVolume;
	///买数量
	ICEVolumeType	BidVolume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///卖开平标志
	ICEOffsetFlagType	AskOffsetFlag;
	///买开平标志
	ICEOffsetFlagType	BidOffsetFlag;
	///卖投机套保标志
	ICEHedgeFlagType	AskHedgeFlag;
	///买投机套保标志
	ICEHedgeFlagType	BidHedgeFlag;
	///衍生卖报单引用
	ICEOrderRefType	AskOrderRef;
	///衍生买报单引用
	ICEOrderRefType	BidOrderRef;
	///应价编号
	ICEOrderSysIDType	ForQuoteSysID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///交易编码
	ICEClientIDType	ClientID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///输入报价操作
struct ICEInputQuoteActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报价操作引用
	ICEOrderActionRefType	QuoteActionRef;
	///报价引用
	ICEOrderRefType	QuoteRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报价操作编号
	ICEOrderSysIDType	QuoteSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///交易编码
	ICEClientIDType	ClientID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///报价
struct ICEQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报价引用
	ICEOrderRefType	QuoteRef;
	///用户代码
	ICEUserIDType	UserID;
	///卖价格
	ICEPriceType	AskPrice;
	///买价格
	ICEPriceType	BidPrice;
	///卖数量
	ICEVolumeType	AskVolume;
	///买数量
	ICEVolumeType	BidVolume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///卖开平标志
	ICEOffsetFlagType	AskOffsetFlag;
	///买开平标志
	ICEOffsetFlagType	BidOffsetFlag;
	///卖投机套保标志
	ICEHedgeFlagType	AskHedgeFlag;
	///买投机套保标志
	ICEHedgeFlagType	BidHedgeFlag;
	///本地报价编号
	ICEOrderLocalIDType	QuoteLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报价提示序号
	ICESequenceNoType	NotifySequence;
	///报价提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报价编号
	ICEOrderSysIDType	QuoteSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;
	///报价状态
	ICEOrderStatusType	QuoteStatus;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///卖方报单编号
	ICEOrderSysIDType	AskOrderSysID;
	///买方报单编号
	ICEOrderSysIDType	BidOrderSysID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///操作用户代码
	ICEUserIDType	ActiveUserID;
	///经纪公司报价编号
	ICESequenceNoType	BrokerQuoteSeq;
	///衍生卖报单引用
	ICEOrderRefType	AskOrderRef;
	///衍生买报单引用
	ICEOrderRefType	BidOrderRef;
	///应价编号
	ICEOrderSysIDType	ForQuoteSysID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///报价操作
struct ICEQuoteActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报价操作引用
	ICEOrderActionRefType	QuoteActionRef;
	///报价引用
	ICEOrderRefType	QuoteRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报价操作编号
	ICEOrderSysIDType	QuoteSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报价编号
	ICEOrderLocalIDType	QuoteLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///报价查询
struct ICEQryQuoteField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报价编号
	ICEOrderSysIDType	QuoteSysID;
	///开始时间
	ICETimeType	InsertTimeStart;
	///结束时间
	ICETimeType	InsertTimeEnd;
};

///交易所报价信息
struct ICEExchangeQuoteField
{
	///卖价格
	ICEPriceType	AskPrice;
	///买价格
	ICEPriceType	BidPrice;
	///卖数量
	ICEVolumeType	AskVolume;
	///买数量
	ICEVolumeType	BidVolume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///卖开平标志
	ICEOffsetFlagType	AskOffsetFlag;
	///买开平标志
	ICEOffsetFlagType	BidOffsetFlag;
	///卖投机套保标志
	ICEHedgeFlagType	AskHedgeFlag;
	///买投机套保标志
	ICEHedgeFlagType	BidHedgeFlag;
	///本地报价编号
	ICEOrderLocalIDType	QuoteLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报价提示序号
	ICESequenceNoType	NotifySequence;
	///报价提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报价编号
	ICEOrderSysIDType	QuoteSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;
	///报价状态
	ICEOrderStatusType	QuoteStatus;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///卖方报单编号
	ICEOrderSysIDType	AskOrderSysID;
	///买方报单编号
	ICEOrderSysIDType	BidOrderSysID;
	///应价编号
	ICEOrderSysIDType	ForQuoteSysID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所报价查询
struct ICEQryExchangeQuoteField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///报价操作查询
struct ICEQryQuoteActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所报价操作
struct ICEExchangeQuoteActionField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报价操作编号
	ICEOrderSysIDType	QuoteSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报价编号
	ICEOrderLocalIDType	QuoteLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///交易所报价操作查询
struct ICEQryExchangeQuoteActionField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///期权合约delta值
struct ICEOptionInstrDeltaField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///Delta值
	ICERatioType	Delta;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///发给做市商的询价请求
struct ICEForQuoteRspField
{
	///交易日
	ICEDateType	TradingDay;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///询价编号
	ICEOrderSysIDType	ForQuoteSysID;
	///询价时间
	ICETimeType	ForQuoteTime;
	///业务日期
	ICEDateType	ActionDay;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///当前期权合约执行偏移值的详细内容
struct ICEStrikeOffsetField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///执行偏移值
	ICEMoneyType	Offset;
	///行权偏移类型
	ICEStrikeOffsetTypeType	OffsetType;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///期权执行偏移值查询
struct ICEQryStrikeOffsetField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///录入锁定
struct ICEInputLockField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///锁定引用
	ICEOrderRefType	LockRef;//Unsupported
	///用户代码
	ICEUserIDType	UserID;//Unsupported
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///锁定类型
	ICELockTypeType	LockType;
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///锁定
struct ICELockField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///锁定引用
	ICEOrderRefType	LockRef;//Unsupported
	///用户代码
	ICEUserIDType	UserID;
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///锁定类型
	ICELockTypeType	LockType;
	///本地锁定编号
	ICEOrderLocalIDType	LockLocalID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;//Unsupported
	///客户代码
	ICEClientIDType	ClientID;//Unsupported
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;//Unsupported
	///安装编号
	ICEInstallIDType	InstallID;//Unsupported
	///执行宣告提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;//Unsupported
	///报单提示序号
	ICESequenceNoType	NotifySequence;//Unsupported
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///锁定编号
	ICEOrderSysIDType	LockSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;//Unsupported
	///锁定状态
	ICEOrderActionStatusType	LockStatus;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;//Unsupported
	///序号
	ICESequenceNoType	SequenceNo;//Unsupported
	///前置编号
	ICEFrontIDType	FrontID;//Unsupported
	///会话编号
	ICESessionIDType	SessionID;//Unsupported
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;//Unsupported
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///操作用户代码
	ICEUserIDType	ActiveUserID;//Unsupported
	///经纪公司报单编号
	ICESequenceNoType	BrokerLockSeq;//Unsupported
	///营业部编号
	ICEBranchIDType	BranchID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
};

///查询锁定
struct ICEQryLockField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///锁定编号
	ICEOrderSysIDType	LockSysID;
	///开始时间
	ICETimeType	InsertTimeStart;//Unsupported
	///结束时间
	ICETimeType	InsertTimeEnd;//Unsupported
};

///锁定证券仓位
struct ICELockPositionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///数量
	ICEVolumeType	Volume;
	///冻结数量
	ICEVolumeType	FrozenVolume;//Unsupported
};

///查询锁定证券仓位
struct ICEQryLockPositionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;//Unsupported
};

///当前ETF期权合约手续费的详细内容
struct ICEETFOptionInstrCommRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///执行手续费率
	ICERatioType	StrikeRatioByMoney;
	///执行手续费
	ICERatioType	StrikeRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///持仓方向
	ICEPosiDirectionType	PosiDirection;
};

///ETF期权手续费率查询
struct ICEQryETFOptionInstrCommRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///输入的持仓冻结
struct ICEPosiFreezeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///安装编号
	ICEInstallIDType	InstallID;
	///数量
	ICEVolumeType	Volume;
	///冻结原因
	ICEFreezeReasonTypeType	FreezeReasonType;
	///冻结类型
	ICEFreezeTypeType	FreezeType;
};

///查询锁定
struct ICEQryExchangeLockField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///交易所锁定
struct ICEExchangeLockField
{
	///数量
	ICEVolumeType	Volume;
	///请求编号
	ICERequestIDType	RequestID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///锁定类型
	ICELockTypeType	LockType;
	///本地锁定编号
	ICEOrderLocalIDType	LockLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///执行宣告提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///锁定编号
	ICEOrderSysIDType	LockSysID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///撤销时间
	ICETimeType	CancelTime;
	///锁定状态
	ICEOrderActionStatusType	LockStatus;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///营业部编号
	ICEBranchIDType	BranchID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所操作错误
struct ICEExchangeExecOrderActionErrorField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///执行宣告编号
	ICEExecOrderSysIDType	ExecOrderSysID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地执行宣告编号
	ICEOrderLocalIDType	ExecOrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///输入批量报单操作
struct ICEInputBatchOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///用户代码
	ICEUserIDType	UserID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///批量报单操作
struct ICEBatchOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///交易所批量报单操作
struct ICEExchangeBatchOrderActionField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///查询批量报单操作
struct ICEQryBatchOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者持仓限制
struct ICELimitPosiField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICEVolumeType	TotalVolume;
	///多头数量限制
	ICEVolumeType	LongVolume;
	///当日多头开仓数量限制
	ICEVolumeType	OpenVolume;
	///多头持仓金额限制,不再使用
	ICEMoneyType	LongAmount;
	///总数量冻结
	ICEVolumeType	TotalVolumeFrozen;
	///多头数量冻结
	ICEVolumeType	LongVolumeFrozen;
	///当日开仓数量冻结
	ICEVolumeType	OpenVolumeFrozen;
	///多头持仓金额冻结,不再使用
	ICEMoneyType	LongAmountFrozen;
};

///查询投资者持仓限制
struct ICEQryLimitPosiField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///经纪公司持仓限制
struct ICEBrokerLimitPosiField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICELargeVolumeType	TotalVolume;
	///多头数量限制
	ICELargeVolumeType	LongVolume;
	///总数量冻结
	ICELargeVolumeType	TotalVolumeFrozen;
	///多头数量冻结
	ICELargeVolumeType	LongVolumeFrozen;
};

///查询经纪公司持仓限制
struct ICEQryBrokerLimitPosiField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者证券持仓限制
struct ICELimitPosiSField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICEVolumeType	TotalVolume;
	///当日开仓数量限制
	ICEVolumeType	OpenVolume;
	///总数量冻结
	ICEVolumeType	TotalVolumeFrozen;
	///当日开仓数量冻结
	ICEVolumeType	OpenVolumeFrozen;
};

///查询投资者证券持仓限制
struct ICEQryLimitPosiSField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者持仓限制参数
struct ICELimitPosiParamField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICEVolumeType	TotalVolume;
	///多头数量限制
	ICEVolumeType	LongVolume;
	///当日开仓数量限制
	ICEVolumeType	OpenVolume;
	///多头持仓金额限制,不再使用
	ICEMoneyType	LongAmount;
};

///经纪公司持仓限制参数
struct ICEBrokerLimitPosiParamField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICELargeVolumeType	TotalVolume;
	///多头数量限制
	ICELargeVolumeType	LongVolume;
};

///投资者证券持仓限制参数
struct ICELimitPosiParamSField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///总数量限制
	ICEVolumeType	TotalVolume;
	///当日开仓数量限制
	ICEVolumeType	OpenVolume;
};

///输入证券处置操作
struct ICEInputStockDisposalActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///证券处置操作引用
	ICEOrderActionRefType	StockDisposalActionRef;
	///证券处置引用
	ICEOrderRefType	StockDisposalRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///证券处置操作
struct ICEStockDisposalActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///证券处置操作引用
	ICEOrderActionRefType	StockDisposalActionRef;
	///证券处置引用
	ICEOrderRefType	StockDisposalRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地证券处置编号
	ICEOrderLocalIDType	StockDisposalLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///执行类型
	ICEActionTypeType	ActionType;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///证券处置操作查询
struct ICEQryStockDisposalActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所证券处置操作
struct ICEExchangeStockDisposalActionField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地证券处置编号
	ICEOrderLocalIDType	StockDisposalLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///执行类型
	ICEActionTypeType	ActionType;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///错误证券处置操作
struct ICEQryExchangeStockDisposalActionField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询错误证券处置操作
struct ICEQryErrStockDisposalActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///交易所证券处置操作错误
struct ICEExchangeStockDisposalActionErrorField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///证券处置编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地证券处置编号
	ICEOrderLocalIDType	StockDisposalLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///错误证券处置操作
struct ICEErrStockDisposalActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///证券处置操作引用
	ICEOrderActionRefType	StockDisposalActionRef;
	///证券处置引用
	ICEOrderRefType	StockDisposalRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///投资者分级
struct ICEInvestorLevelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投资者分级类型
	ICELevelTypeType	LevelType;
};

///组合合约安全系数
struct ICECombInstrumentGuardField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///
	ICERatioType	GuarantRatio;
};

///组合合约安全系数查询
struct ICEQryCombInstrumentGuardField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///输入的申请组合
struct ICEInputCombActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///组合引用
	ICEOrderRefType	CombActionRef;
	///用户代码
	ICEUserIDType	UserID;
	///买卖方向
	ICEDirectionType	Direction;
	///数量
	ICEVolumeType	Volume;
	///组合指令方向
	ICECombDirectionType	CombDirection;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///申请组合
struct ICECombActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///组合引用
	ICEOrderRefType	CombActionRef;
	///用户代码
	ICEUserIDType	UserID;
	///买卖方向
	ICEDirectionType	Direction;
	///数量
	ICEVolumeType	Volume;
	///组合指令方向
	ICECombDirectionType	CombDirection;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///本地申请组合编号
	ICEOrderLocalIDType	ActionLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///组合状态
	ICEOrderActionStatusType	ActionStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///序号
	ICESequenceNoType	SequenceNo;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///组合编号
	ICETradeIDType	ComTradeID;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///申请组合查询
struct ICEQryCombActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所申请组合信息
struct ICEExchangeCombActionField
{
	///买卖方向
	ICEDirectionType	Direction;
	///数量
	ICEVolumeType	Volume;
	///组合指令方向
	ICECombDirectionType	CombDirection;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///本地申请组合编号
	ICEOrderLocalIDType	ActionLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///组合状态
	ICEOrderActionStatusType	ActionStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///序号
	ICESequenceNoType	SequenceNo;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///组合编号
	ICETradeIDType	ComTradeID;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///交易所申请组合查询
struct ICEQryExchangeCombActionField
{
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///产品报价汇率
struct ICEProductExchRateField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
	///报价币种类型
	ICECurrencyIDType	QuoteCurrencyID;
	///汇率
	ICEExchangeRateType	ExchangeRate;
};

///产品报价汇率查询
struct ICEQryProductExchRateField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
};

///输入的指定
struct ICEInputDesignateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///指定登记引用
	ICEOrderRefType	DesignateRef;
	///用户代码
	ICEUserIDType	UserID;
	///指定方向
	ICEDesignateTypeType	DesignateType;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///指定
struct ICEDesignateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///指定登记引用
	ICEOrderRefType	DesignateRef;
	///用户代码
	ICEUserIDType	UserID;
	///指定方向
	ICEDesignateTypeType	DesignateType;
	///本地指定编号
	ICEOrderLocalIDType	DesignateLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///指定状态
	ICEOrderActionStatusType	DesignateStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///申请指定
struct ICEQryDesignateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所指定信息
struct ICEExchangeDesignateField
{
	///指定方向
	ICEDesignateTypeType	DesignateType;
	///本地指定编号
	ICEOrderLocalIDType	DesignateLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///指定状态
	ICEOrderActionStatusType	DesignateStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///营业部编号
	ICEBranchIDType	BranchID;
};

///输入的证券处置
struct ICEInputStockDisposalField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///证券处置登记引用
	ICEOrderRefType	StockDisposalRef;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///数量
	ICEVolumeType	Volume;
	///证券处置方向
	ICEStockDisposalTypeType	StockDisposalType;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///证券处置
struct ICEStockDisposalField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///证券处置登记引用
	ICEOrderRefType	StockDisposalRef;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///数量
	ICEVolumeType	Volume;
	///证券处置方向
	ICEStockDisposalTypeType	StockDisposalType;
	///本地证券处置编号
	ICEOrderLocalIDType	StockDisposalLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///证券处置状态
	ICEStockDisposalStatusType	StockDisposalStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///营业部编号
	ICEBranchIDType	BranchID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
};

///申请证券处置
struct ICEQryStockDisposalField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所证券处置信息
struct ICEExchangeStockDisposalField
{
	///数量
	ICEVolumeType	Volume;
	///证券处置方向
	ICEStockDisposalTypeType	StockDisposalType;
	///本地证券处置编号
	ICEOrderLocalIDType	StockDisposalLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///证券处置状态
	ICEStockDisposalStatusType	StockDisposalStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单日期
	ICEDateType	InsertDate;
	///插入时间
	ICETimeType	InsertTime;
	///营业部编号
	ICEBranchIDType	BranchID;
	///证券处置操作编号
	ICEStockDisposalSysIDType	StockDisposalSysID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
};

///查询投资者分级
struct ICEQryInvestorLevelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询询价价差参数
struct ICEQryForQuoteParamField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///询价价差参数
struct ICEForQuoteParamField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///最新价
	ICEPriceType	LastPrice;
	///价差
	ICEPriceType	PriceInterval;
};

///查询行权冻结
struct ICEQryExecFreezeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///行权冻结
struct ICEExecFreezeField
{
	///标的合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///持仓多空方向
	ICEPosiDirectionType	PosiDirection;
	///期权类型
	ICEOptionsTypeType	OptionsType;
	///冻结的数量_单位股
	ICEVolumeType	Volume;
	///冻结金额
	ICEMoneyType	FrozenAmount;
};

///当前做市商期权合约手续费的详细内容
struct ICEMMOptionInstrCommRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///执行手续费率
	ICERatioType	StrikeRatioByMoney;
	///执行手续费
	ICERatioType	StrikeRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///做市商期权手续费率查询
struct ICEQryMMOptionInstrCommRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///做市商合约手续费率
struct ICEMMInstrumentCommissionRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///开仓手续费率
	ICERatioType	OpenRatioByMoney;
	///开仓手续费
	ICERatioType	OpenRatioByVolume;
	///平仓手续费率
	ICERatioType	CloseRatioByMoney;
	///平仓手续费
	ICERatioType	CloseRatioByVolume;
	///平今手续费率
	ICERatioType	CloseTodayRatioByMoney;
	///平今手续费
	ICERatioType	CloseTodayRatioByVolume;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询做市商合约手续费率
struct ICEQryMMInstrumentCommissionRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///当前报单手续费的详细内容
struct ICEInstrumentOrderCommRateField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///报单手续费
	ICERatioType	OrderCommByVolume;
	///撤单手续费
	ICERatioType	OrderActionCommByVolume;
};

///报单手续费率查询
struct ICEQryInstrumentOrderCommRateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者金额限制
struct ICELimitAmountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///多头持仓金额限制
	ICEMoneyType	LongAmount;
	///多头持仓金额冻结
	ICEMoneyType	LongAmountFrozen;
};

///查询投资者金额限制
struct ICEQryLimitAmountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者金额限制参数
struct ICELimitAmountParamField
{
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///多头持仓金额限制
	ICEMoneyType	LongAmount;
};

///当前期权合约保证金保障系数
struct ICEOptionInstrMarginGuardField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机空头保证金调整系数
	ICERatioType	SShortMarginRatioByMoney;
	///投机空头保证金调整系数
	ICEMoneyType	SShortMarginRatioByVolume;
	///保值空头保证金调整系数
	ICERatioType	HShortMarginRatioByMoney;
	///保值空头保证金调整系数
	ICEMoneyType	HShortMarginRatioByVolume;
	///套利空头保证金调整系数
	ICERatioType	AShortMarginRatioByMoney;
	///套利空头保证金调整系数
	ICEMoneyType	AShortMarginRatioByVolume;
	///是否跟随交易所收取
	ICEBoolType	IsRelative;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///市场行情
struct ICEMarketDataField
{
	///交易日
	ICEDateType	TradingDay;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///最新价
	ICEPriceType	LastPrice;
	///上次结算价
	ICEPriceType	PreSettlementPrice;
	///昨收盘
	ICEPriceType	PreClosePrice;
	///昨持仓量
	ICELargeVolumeType	PreOpenInterest;
	///今开盘
	ICEPriceType	OpenPrice;
	///最高价
	ICEPriceType	HighestPrice;
	///最低价
	ICEPriceType	LowestPrice;
	///数量
	ICEVolumeType	Volume;
	///成交金额
	ICEMoneyType	Turnover;
	///持仓量
	ICELargeVolumeType	OpenInterest;
	///今收盘
	ICEPriceType	ClosePrice;
	///本次结算价
	ICEPriceType	SettlementPrice;
	///涨停板价
	ICEPriceType	UpperLimitPrice;
	///跌停板价
	ICEPriceType	LowerLimitPrice;
	///昨虚实度
	ICERatioType	PreDelta;
	///今虚实度
	ICERatioType	CurrDelta;
	///最后修改时间
	ICETimeType	UpdateTime;
	///最后修改毫秒
	ICEMillisecType	UpdateMillisec;
	///业务日期
	ICEDateType	ActionDay;
};

///行情基础属性
struct ICEMarketDataBaseField
{
	///交易日
	ICEDateType	TradingDay;
	///上次结算价
	ICEPriceType	PreSettlementPrice;
	///昨收盘
	ICEPriceType	PreClosePrice;
	///昨持仓量
	ICELargeVolumeType	PreOpenInterest;
	///昨虚实度
	ICERatioType	PreDelta;
};

///行情静态属性
struct ICEMarketDataStaticField
{
	///今开盘
	ICEPriceType	OpenPrice;
	///最高价
	ICEPriceType	HighestPrice;
	///最低价
	ICEPriceType	LowestPrice;
	///今收盘
	ICEPriceType	ClosePrice;
	///涨停板价
	ICEPriceType	UpperLimitPrice;
	///跌停板价
	ICEPriceType	LowerLimitPrice;
	///本次结算价
	ICEPriceType	SettlementPrice;
	///今虚实度
	ICERatioType	CurrDelta;
};

///行情最新成交属性
struct ICEMarketDataLastMatchField
{
	///最新价
	ICEPriceType	LastPrice;
	///数量
	ICEVolumeType	Volume;
	///成交金额
	ICEMoneyType	Turnover;
	///持仓量
	ICELargeVolumeType	OpenInterest;
};

///行情最优价属性
struct ICEMarketDataBestPriceField
{
	///申买价一
	ICEPriceType	BidPrice1;
	///申买量一
	ICEVolumeType	BidVolume1;
	///申卖价一
	ICEPriceType	AskPrice1;
	///申卖量一
	ICEVolumeType	AskVolume1;
};

///行情申买二、三属性
struct ICEMarketDataBid23Field
{
	///申买价二
	ICEPriceType	BidPrice2;
	///申买量二
	ICEVolumeType	BidVolume2;
	///申买价三
	ICEPriceType	BidPrice3;
	///申买量三
	ICEVolumeType	BidVolume3;
};

///行情申卖二、三属性
struct ICEMarketDataAsk23Field
{
	///申卖价二
	ICEPriceType	AskPrice2;
	///申卖量二
	ICEVolumeType	AskVolume2;
	///申卖价三
	ICEPriceType	AskPrice3;
	///申卖量三
	ICEVolumeType	AskVolume3;
};

///行情申买四、五属性
struct ICEMarketDataBid45Field
{
	///申买价四
	ICEPriceType	BidPrice4;
	///申买量四
	ICEVolumeType	BidVolume4;
	///申买价五
	ICEPriceType	BidPrice5;
	///申买量五
	ICEVolumeType	BidVolume5;
};

///行情申卖四、五属性
struct ICEMarketDataAsk45Field
{
	///申卖价四
	ICEPriceType	AskPrice4;
	///申卖量四
	ICEVolumeType	AskVolume4;
	///申卖价五
	ICEPriceType	AskPrice5;
	///申卖量五
	ICEVolumeType	AskVolume5;
};

///行情更新时间属性
struct ICEMarketDataUpdateTimeField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///最后修改时间
	ICETimeType	UpdateTime;
	///最后修改毫秒
	ICEMillisecType	UpdateMillisec;
	///业务日期
	ICEDateType	ActionDay;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///行情交易所代码属性
struct ICEMarketDataExchangeField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///指定的合约
struct ICESpecificInstrumentField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///合约状态
struct ICEInstrumentStatusField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///结算组代码
	ICESettlementGroupIDType	SettlementGroupID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///合约交易状态
	ICEInstrumentStatusType	InstrumentStatus;
	///交易阶段编号
	ICETradingSegmentSNType	TradingSegmentSN;
	///进入本状态时间
	ICETimeType	EnterTime;
	///进入本状态原因
	ICEInstStatusEnterReasonType	EnterReason;
};

///查询合约状态
struct ICEQryInstrumentStatusField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
};

///投资者账户
struct ICEInvestorAccountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///业务类型
	ICEBizTypeType	BizType;
};

///浮动盈亏算法
struct ICEPositionProfitAlgorithmField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///盈亏算法
	ICEAlgorithmType	Algorithm;
	///备注
	ICEMemoType	Memo;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///会员资金折扣
struct ICEDiscountField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///资金折扣比例
	ICERatioType	Discount;
};

///查询转帐银行
struct ICEQryTransferBankField
{
	///银行代码
	ICEBankIDType	BankID;
	///银行分中心代码
	ICEBankBrchIDType	BankBrchID;
};

///转帐银行
struct ICETransferBankField
{
	///银行代码
	ICEBankIDType	BankID;
	///银行分中心代码
	ICEBankBrchIDType	BankBrchID;
	///银行名称
	ICEBankNameType	BankName;
	///是否活跃
	ICEBoolType	IsActive;//Unsupported
};

///查询投资者持仓明细
struct ICEQryInvestorPositionDetailField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者持仓明细
struct ICEInvestorPositionDetailField
{
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;//Unsupported
	///买卖
	ICEDirectionType	Direction;
	///开仓日期
	ICEDateType	OpenDate;
	///成交编号
	ICETradeIDType	TradeID;//Unsupported
	///数量
	ICEVolumeType	Volume;
	///开仓价
	ICEPriceType	OpenPrice;
	///交易日
	ICEDateType	TradingDay;//Unsupported
	///结算编号
	ICESettlementIDType	SettlementID;//Unsupported
	///成交类型
	ICETradeTypeType	TradeType;//Unsupported
	///组合合约代码
	ICEInstrumentIDType	CombInstrumentID;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///逐日盯市平仓盈亏
	ICEMoneyType	CloseProfitByDate;
	///逐笔对冲平仓盈亏
	ICEMoneyType	CloseProfitByTrade;
	///逐日盯市持仓盈亏
	ICEMoneyType	PositionProfitByDate;
	///逐笔对冲持仓盈亏
	ICEMoneyType	PositionProfitByTrade;
	///投资者保证金
	ICEMoneyType	Margin;//Unsupported
	///交易所保证金
	ICEMoneyType	ExchMargin;//Unsupported
	///保证金率
	ICERatioType	MarginRateByMoney;
	///保证金率(按手数)
	ICERatioType	MarginRateByVolume;
	///昨结算价
	ICEPriceType	LastSettlementPrice;
	///结算价
	ICEPriceType	SettlementPrice;
	///平仓量
	ICEVolumeType	CloseVolume;
	///平仓金额
	ICEMoneyType	CloseAmount;//Unsupported
};

///资金账户口令域
struct ICETradingAccountPasswordField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///密码
	ICEPasswordType	Password;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///交易所行情报盘机
struct ICEMDTraderOfferField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///交易所交易员连接状态
	ICETraderConnectStatusType	TraderConnectStatus;
	///发出连接请求的日期
	ICEDateType	ConnectRequestDate;
	///发出连接请求的时间
	ICETimeType	ConnectRequestTime;
	///上次报告日期
	ICEDateType	LastReportDate;
	///上次报告时间
	ICETimeType	LastReportTime;
	///完成连接日期
	ICEDateType	ConnectDate;
	///完成连接时间
	ICETimeType	ConnectTime;
	///启动日期
	ICEDateType	StartDate;
	///启动时间
	ICETimeType	StartTime;
	///交易日
	ICEDateType	TradingDay;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///本席位最大成交编号
	ICETradeIDType	MaxTradeID;
	///本席位最大报单备拷
	ICEReturnCodeType	MaxOrderMessageReference;
	///业务类型
	ICEBizTypeType	BizType;
};

///查询行情报盘机
struct ICEQryMDTraderOfferField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
};

///查询客户通知
struct ICEQryNoticeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///客户通知
struct ICENoticeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///消息正文
	ICEContentType	Content;
	///经纪公司通知内容序列号
	ICESequenceLabelType	SequenceLabel;
};

///用户权限
struct ICEUserRightField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///客户权限类型
	ICEUserRightTypeType	UserRightType;
	///是否禁止
	ICEBoolType	IsForbidden;
};

///查询结算信息确认域
struct ICEQrySettlementInfoConfirmField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///装载结算信息
struct ICELoadSettlementInfoField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///经纪公司可提资金算法表
struct ICEBrokerWithdrawAlgorithmField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///可提资金算法
	ICEAlgorithmType	WithdrawAlgorithm;
	///资金使用率
	ICERatioType	UsingRatio;
	///可提是否包含平仓盈利
	ICEIncludeCloseProfitType	IncludeCloseProfit;
	///本日无仓且无成交客户是否受可提比例限制
	ICEAllWithoutTradeType	AllWithoutTrade;
	///可用是否包含平仓盈利
	ICEIncludeCloseProfitType	AvailIncludeCloseProfit;
	///是否启用用户事件
	ICEBoolType	IsBrokerUserEvent;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///货币质押比率
	ICERatioType	FundMortgageRatio;
	///权益算法
	ICEBalanceAlgorithmType	BalanceAlgorithm;
};

///资金账户口令变更域
struct ICETradingAccountPasswordUpdateV1Field
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///原来的口令
	ICEPasswordType	OldPassword;
	///新的口令
	ICEPasswordType	NewPassword;
};

///资金账户口令变更域
struct ICETradingAccountPasswordUpdateField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///原来的口令
	ICEPasswordType	OldPassword;
	///新的口令
	ICEPasswordType	NewPassword;
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
};

///查询组合合约分腿
struct ICEQryCombinationLegField
{
	///组合合约代码
	ICEInstrumentIDType	CombInstrumentID;
	///单腿编号
	ICELegIDType	LegID;
	///单腿合约代码
	ICEInstrumentIDType	LegInstrumentID;
};

///查询组合合约分腿
struct ICEQrySyncStatusField
{
	///交易日
	ICEDateType	TradingDay;
};

///组合交易合约的单腿
struct ICECombinationLegField
{
	///组合合约代码
	ICEInstrumentIDType	CombInstrumentID;
	///单腿编号
	ICELegIDType	LegID;
	///单腿合约代码
	ICEInstrumentIDType	LegInstrumentID;
	///买卖方向
	ICEDirectionType	Direction;
	///单腿乘数
	ICELegMultipleType	LegMultiple;
	///派生层数
	ICEImplyLevelType	ImplyLevel;
};

///数据同步状态
struct ICESyncStatusField
{
	///交易日
	ICEDateType	TradingDay;
	///数据同步状态
	ICEDataSyncStatusType	DataSyncStatus;
};

///查询联系人
struct ICEQryLinkManField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///联系人
struct ICELinkManField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///联系人类型
	ICEPersonTypeType	PersonType;
	///证件类型
	ICEIdCardTypeType	IdentifiedCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///名称
	ICEPartyNameType	PersonName;
	///联系电话
	ICETelephoneType	Telephone;
	///通讯地址
	ICEAddressType	Address;
	///邮政编码
	ICEZipCodeType	ZipCode;
	///优先级
	ICEPriorityType	Priority;
	///开户邮政编码
	ICEUOAZipCodeType	UOAZipCode;
	///全称
	ICEInvestorFullNameType	PersonFullName;
};

///查询经纪公司用户事件
struct ICEQryBrokerUserEventField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户事件类型
	ICEUserEventTypeType	UserEventType;
};

///查询经纪公司用户事件
struct ICEBrokerUserEventField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///用户事件类型
	ICEUserEventTypeType	UserEventType;
	///用户事件序号
	ICESequenceNoType	EventSequenceNo;
	///事件发生日期
	ICEDateType	EventDate;
	///事件发生时间
	ICETimeType	EventTime;
	///用户事件信息
	ICEUserEventInfoType	UserEventInfo;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询签约银行请求
struct ICEQryContractBankField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///银行代码
	ICEBankIDType	BankID;
	///银行分中心代码
	ICEBankBrchIDType	BankBrchID;
};

///查询签约银行响应
struct ICEContractBankField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///银行代码
	ICEBankIDType	BankID;
	///银行分中心代码
	ICEBankBrchIDType	BankBrchID;
	///银行名称
	ICEBankNameType	BankName;
};

///投资者组合持仓明细
struct ICEInvestorPositionCombineDetailField
{
	///交易日
	ICEDateType	TradingDay;
	///开仓日期
	ICEDateType	OpenDate;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///结算编号
	ICESettlementIDType	SettlementID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///组合编号
	ICETradeIDType	ComTradeID;
	///撮合编号
	ICETradeIDType	TradeID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///买卖
	ICEDirectionType	Direction;
	///持仓量
	ICEVolumeType	TotalAmt;
	///投资者保证金
	ICEMoneyType	Margin;
	///交易所保证金
	ICEMoneyType	ExchMargin;
	///保证金率
	ICERatioType	MarginRateByMoney;
	///保证金率(按手数)
	ICERatioType	MarginRateByVolume;
	///单腿编号
	ICELegIDType	LegID;
	///单腿乘数
	ICELegMultipleType	LegMultiple;
	///组合持仓合约编码
	ICEInstrumentIDType	CombInstrumentID;
	///成交组号
	ICETradeGroupIDType	TradeGroupID;
};

///预埋单
struct ICEParkedOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;//Unsupported
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;//Unsupported
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;//Unsupported
	///触发条件
	ICEContingentConditionType	ContingentCondition;//Unsupported
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;//Unsupported
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;//Unsupported
	///业务单元
	ICEBusinessUnitType	BusinessUnit;//Unsupported
	///请求编号
	ICERequestIDType	RequestID;//Unsupported
	///用户强评标志
	ICEBoolType	UserForceClose;//Unsupported
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///预埋报单编号
	ICEParkedOrderIDType	ParkedOrderID;
	///用户类型
	ICEUserTypeType	UserType;//Unsupported
	///预埋单状态
	ICEParkedOrderStatusType	Status;
	///错误代码
	ICEErrorIDType	ErrorID;//Unsupported
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///互换单标志
	ICEBoolType	IsSwapOrder;//Unsupported
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
	///交易编码
	ICEClientIDType	ClientID;//Unsupported
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;//Unsupported
	///IP地址
	ICEIPAddressType	IPAddress;//Unsupported
	///Mac地址
	ICEMacAddressType	MacAddress;//Unsupported
	///自適應
	ICEBoolType			IsFitOrderFreq;
	///TCore 报单编号
	ICEOrderSysIDType	ReportID;
};

///输入预埋单操作
struct ICEParkedOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;
	///报单引用
	ICEOrderRefType	OrderRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量变化
	ICEVolumeType	VolumeChange;
	///用户代码
	ICEUserIDType	UserID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///预埋撤单单编号
	ICEParkedOrderActionIDType	ParkedOrderActionID;
	///用户类型
	ICEUserTypeType	UserType;
	///预埋撤单状态
	ICEParkedOrderStatusType	Status;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///查询预埋单
struct ICEQryParkedOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询预埋撤单
struct ICEQryParkedOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///删除预埋单
struct ICERemoveParkedOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;//Unsupported
	///投资者代码
	ICEInvestorIDType	InvestorID;//Unsupported
	///预埋报单编号
	ICEParkedOrderIDType	ParkedOrderID;//Unsupported
	///TCore 报单编号
	ICEOrderSysIDType	ReportID;
};

///删除预埋撤单
struct ICERemoveParkedOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///预埋撤单编号
	ICEParkedOrderActionIDType	ParkedOrderActionID;
};

///经纪公司可提资金算法表
struct ICEInvestorWithdrawAlgorithmField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///可提资金比例
	ICERatioType	UsingRatio;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///货币质押比率
	ICERatioType	FundMortgageRatio;
};

///查询组合持仓明细
struct ICEQryInvestorPositionCombineDetailField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///组合持仓合约编码
	ICEInstrumentIDType	CombInstrumentID;
};

///成交均价
struct ICEMarketDataAveragePriceField
{
	///当日均价
	ICEPriceType	AveragePrice;
};

///校验投资者密码
struct ICEVerifyInvestorPasswordField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///密码
	ICEPasswordType	Password;
};

///用户IP
struct ICEUserIPField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///IP地址掩码
	ICEIPAddressType	IPMask;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///用户事件通知信息
struct ICETradingNoticeInfoField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;//Unsupported
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///发送时间
	ICETimeType	SendTime;
	///消息正文
	ICEContentType	FieldContent;
	///序列系列号
	ICESequenceSeriesType	SequenceSeries;//Unsupported
	///序列号
	ICESequenceNoType	SequenceNo;//Unsupported
};

///用户事件通知
struct ICETradingNoticeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者范围
	ICEInvestorRangeType	InvestorRange;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///序列系列号
	ICESequenceSeriesType	SequenceSeries;
	///用户代码
	ICEUserIDType	UserID;
	///发送时间
	ICETimeType	SendTime;
	///序列号
	ICESequenceNoType	SequenceNo;
	///消息正文
	ICEContentType	FieldContent;
};

///查询交易事件通知
struct ICEQryTradingNoticeField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///查询错误报单
struct ICEQryErrOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///错误报单
struct ICEErrOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;
	///触发条件
	ICEContingentConditionType	ContingentCondition;
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///请求编号
	ICERequestIDType	RequestID;
	///用户强评标志
	ICEBoolType	UserForceClose;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///互换单标志
	ICEBoolType	IsSwapOrder;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///交易编码
	ICEClientIDType	ClientID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///查询错误报单操作
struct ICEErrorConditionalOrderField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///报单引用
	ICEOrderRefType	OrderRef;
	///用户代码
	ICEUserIDType	UserID;
	///报单价格条件
	ICEOrderPriceTypeType	OrderPriceType;
	///买卖方向
	ICEDirectionType	Direction;
	///组合开平标志
	ICECombOffsetFlagType	CombOffsetFlag;
	///组合投机套保标志
	ICECombHedgeFlagType	CombHedgeFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量
	ICEVolumeType	VolumeTotalOriginal;
	///有效期类型
	ICETimeConditionType	TimeCondition;
	///GTD日期
	ICEDateType	GTDDate;
	///成交量类型
	ICEVolumeConditionType	VolumeCondition;
	///最小成交量
	ICEVolumeType	MinVolume;
	///触发条件
	ICEContingentConditionType	ContingentCondition;
	///止损价
	ICEPriceType	StopPrice;
	///强平原因
	ICEForceCloseReasonType	ForceCloseReason;
	///自动挂起标志
	ICEBoolType	IsAutoSuspend;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///请求编号
	ICERequestIDType	RequestID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///合约在交易所的代码
	ICEExchangeInstIDType	ExchangeInstID;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///报单提交状态
	ICEOrderSubmitStatusType	OrderSubmitStatus;
	///报单提示序号
	ICESequenceNoType	NotifySequence;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///报单来源
	ICEOrderSourceType	OrderSource;
	///报单状态
	ICEOrderStatusType	OrderStatus;
	///报单类型
	ICEOrderTypeType	OrderType;
	///今成交数量
	ICEVolumeType	VolumeTraded;
	///剩余数量
	ICEVolumeType	VolumeTotal;
	///报单日期
	ICEDateType	InsertDate;
	///委托时间
	ICETimeType	InsertTime;
	///激活时间
	ICETimeType	ActiveTime;
	///挂起时间
	ICETimeType	SuspendTime;
	///最后修改时间
	ICETimeType	UpdateTime;
	///撤销时间
	ICETimeType	CancelTime;
	///最后修改交易所交易员代码
	ICETraderIDType	ActiveTraderID;
	///结算会员编号
	ICEParticipantIDType	ClearingPartID;
	///序号
	ICESequenceNoType	SequenceNo;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///用户端产品信息
	ICEProductInfoType	UserProductInfo;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///用户强评标志
	ICEBoolType	UserForceClose;
	///操作用户代码
	ICEUserIDType	ActiveUserID;
	///经纪公司报单编号
	ICESequenceNoType	BrokerOrderSeq;
	///相关报单
	ICEOrderSysIDType	RelativeOrderSysID;
	///郑商所成交数量
	ICEVolumeType	ZCETotalTradedVolume;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///互换单标志
	ICEBoolType	IsSwapOrder;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///资金账号
	ICEAccountIDType	AccountID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
};

///查询错误报单操作
struct ICEQryErrOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///错误报单操作
struct ICEErrOrderActionField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///报单操作引用
	ICEOrderActionRefType	OrderActionRef;
	///报单引用
	ICEOrderRefType	OrderRef;
	///请求编号
	ICERequestIDType	RequestID;
	///前置编号
	ICEFrontIDType	FrontID;
	///会话编号
	ICESessionIDType	SessionID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///报单编号
	ICEOrderSysIDType	OrderSysID;
	///操作标志
	ICEActionFlagType	ActionFlag;
	///价格
	ICEPriceType	LimitPrice;
	///数量变化
	ICEVolumeType	VolumeChange;
	///操作日期
	ICEDateType	ActionDate;
	///操作时间
	ICETimeType	ActionTime;
	///交易所交易员代码
	ICETraderIDType	TraderID;
	///安装编号
	ICEInstallIDType	InstallID;
	///本地报单编号
	ICEOrderLocalIDType	OrderLocalID;
	///操作本地编号
	ICEOrderLocalIDType	ActionLocalID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///客户代码
	ICEClientIDType	ClientID;
	///业务单元
	ICEBusinessUnitType	BusinessUnit;
	///报单操作状态
	ICEOrderActionStatusType	OrderActionStatus;
	///用户代码
	ICEUserIDType	UserID;
	///状态信息
	ICEErrorMsgType	StatusMsg;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///营业部编号
	ICEBranchIDType	BranchID;
	///投资单元代码
	ICEInvestUnitIDType	InvestUnitID;
	///IP地址
	ICEIPAddressType	IPAddress;
	///Mac地址
	ICEMacAddressType	MacAddress;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询交易所状态
struct ICEQryExchangeSequenceField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///交易所状态
struct ICEExchangeSequenceField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///序号
	ICESequenceNoType	SequenceNo;
	///合约交易状态
	ICEInstrumentStatusType	MarketStatus;
};

///根据价格查询最大报单数量
struct ICEQueryMaxOrderVolumeWithPriceField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///买卖方向
	ICEDirectionType	Direction;
	///开平标志
	ICEOffsetFlagType	OffsetFlag;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///最大允许报单数量
	ICEVolumeType	MaxVolume;
	///报单价格
	ICEPriceType	Price;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///查询经纪公司交易参数
struct ICEQryBrokerTradingParamsField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///经纪公司交易参数
struct ICEBrokerTradingParamsField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///保证金价格类型
	ICEMarginPriceTypeType	MarginPriceType;
	///盈亏算法
	ICEAlgorithmType	Algorithm;
	///可用是否包含平仓盈利
	ICEIncludeCloseProfitType	AvailIncludeCloseProfit;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///期权权利金价格类型
	ICEOptionRoyaltyPriceTypeType	OptionRoyaltyPriceType;
};

///查询经纪公司交易算法
struct ICEQryBrokerTradingAlgosField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///经纪公司交易算法
struct ICEBrokerTradingAlgosField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///持仓处理算法编号
	ICEHandlePositionAlgoIDType	HandlePositionAlgoID;
	///寻找保证金率算法编号
	ICEFindMarginRateAlgoIDType	FindMarginRateAlgoID;
	///资金处理算法编号
	ICEHandleTradingAccountAlgoIDType	HandleTradingAccountAlgoID;
};

///查询经纪公司资金
struct ICEQueryBrokerDepositField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///经纪公司资金
struct ICEBrokerDepositField
{
	///交易日期
	ICETradeDateType	TradingDay;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///会员代码
	ICEParticipantIDType	ParticipantID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///上次结算准备金
	ICEMoneyType	PreBalance;
	///当前保证金总额
	ICEMoneyType	CurrMargin;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///期货结算准备金
	ICEMoneyType	Balance;
	///入金金额
	ICEMoneyType	Deposit;
	///出金金额
	ICEMoneyType	Withdraw;
	///可提资金
	ICEMoneyType	Available;
	///基本准备金
	ICEMoneyType	Reserve;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
};

///查询保证金监管系统经纪公司密钥
struct ICEQryCFMMCBrokerKeyField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
};

///保证金监管系统经纪公司密钥
struct ICECFMMCBrokerKeyField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///经纪公司统一编码
	ICEParticipantIDType	ParticipantID;
	///密钥生成日期
	ICEDateType	CreateDate;
	///密钥生成时间
	ICETimeType	CreateTime;
	///密钥编号
	ICESequenceNoType	KeyID;
	///动态密钥
	ICECFMMCKeyType	CurrentKey;
	///动态密钥类型
	ICECFMMCKeyKindType	KeyKind;
};

///保证金监管系统经纪公司资金账户密钥
struct ICECFMMCTradingAccountKeyField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///经纪公司统一编码
	ICEParticipantIDType	ParticipantID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///密钥编号
	ICESequenceNoType	KeyID;
	///动态密钥
	ICECFMMCKeyType	CurrentKey;
};

///请求查询保证金监管系统经纪公司资金账户密钥
struct ICEQryCFMMCTradingAccountKeyField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///用户动态令牌参数
struct ICEBrokerUserOTPParamField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///动态令牌提供商
	ICEOTPVendorsIDType	OTPVendorsID;
	///动态令牌序列号
	ICESerialNumberType	SerialNumber;
	///令牌密钥
	ICEAuthKeyType	AuthKey;
	///漂移值
	ICELastDriftType	LastDrift;
	///成功值
	ICELastSuccessType	LastSuccess;
	///动态令牌类型
	ICEOTPTypeType	OTPType;
};

///手工同步用户动态令牌
struct ICEManualSyncBrokerUserOTPField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///动态令牌类型
	ICEOTPTypeType	OTPType;
	///第一个动态密码
	ICEPasswordType	FirstOTP;
	///第二个动态密码
	ICEPasswordType	SecondOTP;
};

///投资者手续费率模板
struct ICECommRateModelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///手续费率模板代码
	ICEInvestorIDType	CommModelID;
	///模板名称
	ICECommModelNameType	CommModelName;
};

///请求查询投资者手续费率模板
struct ICEQryCommRateModelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///手续费率模板代码
	ICEInvestorIDType	CommModelID;
};

///投资者保证金率模板
struct ICEMarginModelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///保证金率模板代码
	ICEInvestorIDType	MarginModelID;
	///模板名称
	ICECommModelNameType	MarginModelName;
};

///请求查询投资者保证金率模板
struct ICEQryMarginModelField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///保证金率模板代码
	ICEInvestorIDType	MarginModelID;
};

///仓单折抵信息
struct ICEEWarrantOffsetField
{
	///交易日期
	ICETradeDateType	TradingDay;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
	///买卖方向
	ICEDirectionType	Direction;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
	///数量
	ICEVolumeType	Volume;
};

///查询仓单折抵信息
struct ICEQryEWarrantOffsetField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///合约代码
	ICEInstrumentIDType	InstrumentID;
};

///查询投资者品种/跨品种保证金
struct ICEQryInvestorProductGroupMarginField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///品种/跨品种标示
	ICEInstrumentIDType	ProductGroupID;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///投资者品种/跨品种保证金
struct ICEInvestorProductGroupMarginField
{
	///品种/跨品种标示
	ICEInstrumentIDType	ProductGroupID;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///交易日
	ICEDateType	TradingDay;
	///结算编号
	ICESettlementIDType	SettlementID;
	///冻结的保证金
	ICEMoneyType	FrozenMargin;
	///多头冻结的保证金
	ICEMoneyType	LongFrozenMargin;
	///空头冻结的保证金
	ICEMoneyType	ShortFrozenMargin;
	///占用的保证金
	ICEMoneyType	UseMargin;
	///多头保证金
	ICEMoneyType	LongUseMargin;
	///空头保证金
	ICEMoneyType	ShortUseMargin;
	///交易所保证金
	ICEMoneyType	ExchMargin;
	///交易所多头保证金
	ICEMoneyType	LongExchMargin;
	///交易所空头保证金
	ICEMoneyType	ShortExchMargin;
	///平仓盈亏
	ICEMoneyType	CloseProfit;
	///冻结的手续费
	ICEMoneyType	FrozenCommission;
	///手续费
	ICEMoneyType	Commission;
	///冻结的资金
	ICEMoneyType	FrozenCash;
	///资金差额
	ICEMoneyType	CashIn;
	///持仓盈亏
	ICEMoneyType	PositionProfit;
	///折抵总金额
	ICEMoneyType	OffsetAmount;
	///多头折抵总金额
	ICEMoneyType	LongOffsetAmount;
	///空头折抵总金额
	ICEMoneyType	ShortOffsetAmount;
	///交易所折抵总金额
	ICEMoneyType	ExchOffsetAmount;
	///交易所多头折抵总金额
	ICEMoneyType	LongExchOffsetAmount;
	///交易所空头折抵总金额
	ICEMoneyType	ShortExchOffsetAmount;
	///投机套保标志
	ICEHedgeFlagType	HedgeFlag;
};

///查询监控中心用户令牌
struct ICEQueryCFMMCTradingAccountTokenField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
};

///监控中心用户令牌
struct ICECFMMCTradingAccountTokenField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///经纪公司统一编码
	ICEParticipantIDType	ParticipantID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///密钥编号
	ICESequenceNoType	KeyID;
	///动态令牌
	ICECFMMCTokenType	Token;
};

///投资者指令权限
struct ICEInstructionRightField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///指令权限类型
	ICEInstructionRightTypeType	InstructionRight;
	///是否禁止
	ICEBoolType	IsForbidden;
};

///查询产品组
struct ICEQryProductGroupField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
};

///投资者品种/跨品种保证金产品组
struct ICEProductGroupField
{
	///产品代码
	ICEInstrumentIDType	ProductID;
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///产品组代码
	ICEInstrumentIDType	ProductGroupID;
};

///交易所公告
struct ICEBulletinField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///交易日
	ICEDateType	TradingDay;
	///公告编号
	ICEBulletinIDType	BulletinID;
	///序列号
	ICESequenceNoType	SequenceNo;
	///公告类型
	ICENewsTypeType	NewsType;
	///紧急程度
	ICENewsUrgencyType	NewsUrgency;
	///发送时间
	ICETimeType	SendTime;
	///消息摘要
	ICEAbstractType	Abstract;
	///消息来源
	ICEComeFromType	ComeFrom;
	///消息正文
	ICEContentType	Content;
	///WEB地址
	ICEURLLinkType	URLLink;
	///市场代码
	ICEMarketIDType	MarketID;
};

///查询交易所公告
struct ICEQryBulletinField
{
	///交易所代码
	ICEExchangeIDType	ExchangeID;
	///公告编号
	ICEBulletinIDType	BulletinID;
	///序列号
	ICESequenceNoType	SequenceNo;
	///公告类型
	ICENewsTypeType	NewsType;
	///紧急程度
	ICENewsUrgencyType	NewsUrgency;
};

///转帐开户请求
struct ICEReqOpenAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///汇钞标志
	ICECashExchangeCodeType	CashExchangeCode;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///交易ID
	ICETIDType	TID;
	///用户标识
	ICEUserIDType	UserID;
};

///转帐销户请求
struct ICEReqCancelAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///汇钞标志
	ICECashExchangeCodeType	CashExchangeCode;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///交易ID
	ICETIDType	TID;
	///用户标识
	ICEUserIDType	UserID;
};

///变更银行账户请求
struct ICEReqChangeAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///新银行帐号
	ICEBankAccountType	NewBankAccount;
	///新银行密码
	ICEPasswordType	NewBankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易ID
	ICETIDType	TID;
	///摘要
	ICEDigestType	Digest;
};

///转账请求
struct ICEReqTransferField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///期货可取金额
	ICETradeAmountType	FutureFetchAmount;
	///费用支付标志
	ICEFeePayFlagType	FeePayFlag;
	///应收客户费用
	ICECustFeeType	CustFee;
	///应收期货公司费用
	ICEFutureFeeType	BrokerFee;
	///发送方给接收方的消息
	ICEAddInfoType	Message;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///转账交易状态
	ICETransferStatusType	TransferStatus;
};

///银行发起银行资金转期货响应
struct ICERspTransferField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///期货可取金额
	ICETradeAmountType	FutureFetchAmount;
	///费用支付标志
	ICEFeePayFlagType	FeePayFlag;
	///应收客户费用
	ICECustFeeType	CustFee;
	///应收期货公司费用
	ICEFutureFeeType	BrokerFee;
	///发送方给接收方的消息
	ICEAddInfoType	Message;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///转账交易状态
	ICETransferStatusType	TransferStatus;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///冲正请求
struct ICEReqRepealField
{
	///冲正时间间隔
	ICERepealTimeIntervalType	RepealTimeInterval;
	///已经冲正次数
	ICERepealedTimesType	RepealedTimes;
	///银行冲正标志
	ICEBankRepealFlagType	BankRepealFlag;
	///期商冲正标志
	ICEBrokerRepealFlagType	BrokerRepealFlag;
	///被冲正平台流水号
	ICEPlateSerialType	PlateRepealSerial;
	///被冲正银行流水号
	ICEBankSerialType	BankRepealSerial;
	///被冲正期货流水号
	ICEFutureSerialType	FutureRepealSerial;
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///期货可取金额
	ICETradeAmountType	FutureFetchAmount;
	///费用支付标志
	ICEFeePayFlagType	FeePayFlag;
	///应收客户费用
	ICECustFeeType	CustFee;
	///应收期货公司费用
	ICEFutureFeeType	BrokerFee;
	///发送方给接收方的消息
	ICEAddInfoType	Message;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///转账交易状态
	ICETransferStatusType	TransferStatus;
};

///冲正响应
struct ICERspRepealField
{
	///冲正时间间隔
	ICERepealTimeIntervalType	RepealTimeInterval;
	///已经冲正次数
	ICERepealedTimesType	RepealedTimes;
	///银行冲正标志
	ICEBankRepealFlagType	BankRepealFlag;
	///期商冲正标志
	ICEBrokerRepealFlagType	BrokerRepealFlag;
	///被冲正平台流水号
	ICEPlateSerialType	PlateRepealSerial;
	///被冲正银行流水号
	ICEBankSerialType	BankRepealSerial;
	///被冲正期货流水号
	ICEFutureSerialType	FutureRepealSerial;
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///期货可取金额
	ICETradeAmountType	FutureFetchAmount;
	///费用支付标志
	ICEFeePayFlagType	FeePayFlag;
	///应收客户费用
	ICECustFeeType	CustFee;
	///应收期货公司费用
	ICEFutureFeeType	BrokerFee;
	///发送方给接收方的消息
	ICEAddInfoType	Message;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///转账交易状态
	ICETransferStatusType	TransferStatus;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询账户信息请求
struct ICEReqQueryAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
};

///查询账户信息响应
struct ICERspQueryAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///银行可用金额
	ICETradeAmountType	BankUseAmount;
	///银行可取金额
	ICETradeAmountType	BankFetchAmount;
};

///期商签到签退
struct ICEFutureSignIOField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
};

///期商签到响应
struct ICERspFutureSignInField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///PIN密钥
	ICEPasswordKeyType	PinKey;
	///MAC密钥
	ICEPasswordKeyType	MacKey;
};

///期商签退请求
struct ICEReqFutureSignOutField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
};

///期商签退响应
struct ICERspFutureSignOutField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询指定流水号的交易结果请求
struct ICEReqQueryTradeResultBySerialField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///流水号
	ICESerialType	Reference;
	///本流水号发布者的机构类型
	ICEInstitutionTypeType	RefrenceIssureType;
	///本流水号发布者机构编码
	ICEOrganCodeType	RefrenceIssure;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///摘要
	ICEDigestType	Digest;
};

///查询指定流水号的交易结果响应
struct ICERspQueryTradeResultBySerialField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///流水号
	ICESerialType	Reference;
	///本流水号发布者的机构类型
	ICEInstitutionTypeType	RefrenceIssureType;
	///本流水号发布者机构编码
	ICEOrganCodeType	RefrenceIssure;
	///原始返回代码
	ICEReturnCodeType	OriginReturnCode;
	///原始返回码描述
	ICEDescrInfoForReturnCodeType	OriginDescrInfoForReturnCode;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///转帐金额
	ICETradeAmountType	TradeAmount;
	///摘要
	ICEDigestType	Digest;
};

///日终文件就绪请求
struct ICEReqDayEndFileReadyField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///文件业务功能
	ICEFileBusinessCodeType	FileBusinessCode;
	///摘要
	ICEDigestType	Digest;
};

///返回结果
struct ICEReturnResultField
{
	///返回代码
	ICEReturnCodeType	ReturnCode;
	///返回码描述
	ICEDescrInfoForReturnCodeType	DescrInfoForReturnCode;
};

///验证期货资金密码
struct ICEVerifyFuturePasswordField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///安装编号
	ICEInstallIDType	InstallID;
	///交易ID
	ICETIDType	TID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///验证客户信息
struct ICEVerifyCustInfoField
{
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
};

///验证期货资金密码和客户信息
struct ICEVerifyFuturePasswordAndCustInfoField
{
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///验证期货资金密码和客户信息
struct ICEDepositResultInformField
{
	///出入金流水号，该流水号为银期报盘返回的流水号
	ICEDepositSeqNoType	DepositSeqNo;
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///入金金额
	ICEMoneyType	Deposit;
	///请求编号
	ICERequestIDType	RequestID;
	///返回代码
	ICEReturnCodeType	ReturnCode;
	///返回码描述
	ICEDescrInfoForReturnCodeType	DescrInfoForReturnCode;
};

///交易核心向银期报盘发出密钥同步请求
struct ICEReqSyncKeyField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///交易核心给银期报盘的消息
	ICEAddInfoType	Message;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
};

///交易核心向银期报盘发出密钥同步响应
struct ICERspSyncKeyField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///交易核心给银期报盘的消息
	ICEAddInfoType	Message;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///查询账户信息通知
struct ICENotifyQueryAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///银行可用金额
	ICETradeAmountType	BankUseAmount;
	///银行可取金额
	ICETradeAmountType	BankFetchAmount;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///银期转账交易流水表
struct ICETransferSerialField
{
	///平台流水号
	ICEPlateSerialType	PlateSerial;
	///交易发起方日期
	ICETradeDateType	TradeDate;
	///交易日期
	ICEDateType	TradingDay;
	///交易时间
	ICETradeTimeType	TradeTime;
	///交易代码
	ICETradeCodeType	TradeCode;
	///会话编号
	ICESessionIDType	SessionID;
	///银行编码
	ICEBankIDType	BankID;
	///银行分支机构编码
	ICEBankBrchIDType	BankBranchID;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///期货公司编码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///期货公司帐号类型
	ICEFutureAccTypeType	FutureAccType;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///投资者代码
	ICEInvestorIDType	InvestorID;
	///期货公司流水号
	ICEFutureSerialType	FutureSerial;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///交易金额
	ICETradeAmountType	TradeAmount;
	///应收客户费用
	ICECustFeeType	CustFee;
	///应收期货公司费用
	ICEFutureFeeType	BrokerFee;
	///有效标志
	ICEAvailabilityFlagType	AvailabilityFlag;
	///操作员
	ICEOperatorCodeType	OperatorCode;
	///新银行帐号
	ICEBankAccountType	BankNewAccount;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///请求查询转帐流水
struct ICEQryTransferSerialField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///银行编码
	ICEBankIDType	BankID;
	///币种代码
	ICECurrencyIDType	CurrencyID;//Unsupported
};

///期商签到通知
struct ICENotifyFutureSignInField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
	///PIN密钥
	ICEPasswordKeyType	PinKey;
	///MAC密钥
	ICEPasswordKeyType	MacKey;
};

///期商签退通知
struct ICENotifyFutureSignOutField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///摘要
	ICEDigestType	Digest;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///交易核心向银期报盘发出密钥同步处理结果的通知
struct ICENotifySyncKeyField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///安装编号
	ICEInstallIDType	InstallID;
	///用户标识
	ICEUserIDType	UserID;
	///交易核心给银期报盘的消息
	ICEAddInfoType	Message;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///交易柜员
	ICEOperNoType	OperNo;
	///请求编号
	ICERequestIDType	RequestID;
	///交易ID
	ICETIDType	TID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///请求查询银期签约关系
struct ICEQryAccountregisterField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///银行编码
	ICEBankIDType	BankID;
	///银行分支机构编码
	ICEBankBrchIDType	BankBranchID;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///客户开销户信息表
struct ICEAccountregisterField
{
	///交易日期
	ICETradeDateType	TradeDay;
	///银行编码
	ICEBankIDType	BankID;
	///银行分支机构编码
	ICEBankBrchIDType	BankBranchID;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///期货公司编码
	ICEBrokerIDType	BrokerID;
	///期货公司分支机构编码
	ICEFutureBranchIDType	BrokerBranchID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///开销户类别
	ICEOpenOrDestroyType	OpenOrDestroy;
	///签约日期
	ICETradeDateType	RegDate;
	///解约日期
	ICETradeDateType	OutDate;
	///交易ID
	ICETIDType	TID;
	///客户类型
	ICECustTypeType	CustType;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
};

///银期开户信息
struct ICEOpenAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///汇钞标志
	ICECashExchangeCodeType	CashExchangeCode;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///交易ID
	ICETIDType	TID;
	///用户标识
	ICEUserIDType	UserID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///银期销户信息
struct ICECancelAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///汇钞标志
	ICECashExchangeCodeType	CashExchangeCode;
	///摘要
	ICEDigestType	Digest;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///渠道标志
	ICEDeviceIDType	DeviceID;
	///期货单位帐号类型
	ICEBankAccTypeType	BankSecuAccType;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///期货单位帐号
	ICEBankAccountType	BankSecuAcc;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易柜员
	ICEOperNoType	OperNo;
	///交易ID
	ICETIDType	TID;
	///用户标识
	ICEUserIDType	UserID;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///银期变更银行账号信息
struct ICEChangeAccountField
{
	///业务功能码
	ICETradeCodeType	TradeCode;
	///银行代码
	ICEBankIDType	BankID;
	///银行分支机构代码
	ICEBankBrchIDType	BankBranchID;
	///期商代码
	ICEBrokerIDType	BrokerID;
	///期商分支机构代码
	ICEFutureBranchIDType	BrokerBranchID;
	///交易日期
	ICETradeDateType	TradeDate;
	///交易时间
	ICETradeTimeType	TradeTime;
	///银行流水号
	ICEBankSerialType	BankSerial;
	///交易系统日期 
	ICETradeDateType	TradingDay;
	///银期平台消息流水号
	ICESerialType	PlateSerial;
	///最后分片标志
	ICELastFragmentType	LastFragment;
	///会话号
	ICESessionIDType	SessionID;
	///客户姓名
	ICEIndividualNameType	CustomerName;
	///证件类型
	ICEIdCardTypeType	IdCardType;
	///证件号码
	ICEIdentifiedCardNoType	IdentifiedCardNo;
	///性别
	ICEGenderType	Gender;
	///国家代码
	ICECountryCodeType	CountryCode;
	///客户类型
	ICECustTypeType	CustType;
	///地址
	ICEAddressType	Address;
	///邮编
	ICEZipCodeType	ZipCode;
	///电话号码
	ICETelephoneType	Telephone;
	///手机
	ICEMobilePhoneType	MobilePhone;
	///传真
	ICEFaxType	Fax;
	///电子邮件
	ICEEMailType	EMail;
	///资金账户状态
	ICEMoneyAccountStatusType	MoneyAccountStatus;
	///银行帐号
	ICEBankAccountType	BankAccount;
	///银行密码
	ICEPasswordType	BankPassWord;
	///新银行帐号
	ICEBankAccountType	NewBankAccount;
	///新银行密码
	ICEPasswordType	NewBankPassWord;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///期货密码
	ICEPasswordType	Password;
	///银行帐号类型
	ICEBankAccTypeType	BankAccType;
	///安装编号
	ICEInstallIDType	InstallID;
	///验证客户证件号码标志
	ICEYesNoIndicatorType	VerifyCertNoFlag;
	///币种代码
	ICECurrencyIDType	CurrencyID;
	///期货公司银行编码
	ICEBankCodingForFutureType	BrokerIDByBank;
	///银行密码标志
	ICEPwdFlagType	BankPwdFlag;
	///期货资金密码核对标志
	ICEPwdFlagType	SecuPwdFlag;
	///交易ID
	ICETIDType	TID;
	///摘要
	ICEDigestType	Digest;
	///错误代码
	ICEErrorIDType	ErrorID;
	///错误信息
	ICEErrorMsgType	ErrorMsg;
};

///二级代理操作员银期权限
struct ICESecAgentACIDMapField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///资金账户
	ICEAccountIDType	AccountID;
	///币种
	ICECurrencyIDType	CurrencyID;
	///境外中介机构资金帐号
	ICEAccountIDType	BrokerSecAgentID;
};

///二级代理操作员银期权限查询
struct ICEQrySecAgentACIDMapField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///资金账户
	ICEAccountIDType	AccountID;
	///币种
	ICECurrencyIDType	CurrencyID;
};

///灾备中心交易权限
struct ICEUserRightsAssignField
{
	///应用单元代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///交易中心代码
	ICEDRIdentityIDType	DRIdentityID;
};

///经济公司是否有在本标示的交易权限
struct ICEBrokerUserRightAssignField
{
	///应用单元代码
	ICEBrokerIDType	BrokerID;
	///交易中心代码
	ICEDRIdentityIDType	DRIdentityID;
	///能否交易
	ICEBoolType	Tradeable;
};

///灾备交易转换报文
struct ICEDRTransferField
{
	///原交易中心代码
	ICEDRIdentityIDType	OrigDRIdentityID;
	///目标交易中心代码
	ICEDRIdentityIDType	DestDRIdentityID;
	///原应用单元代码
	ICEBrokerIDType	OrigBrokerID;
	///目标易用单元代码
	ICEBrokerIDType	DestBrokerID;
};

///Fens用户信息
struct ICEFensUserInfoField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///登录模式
	ICELoginModeType	LoginMode;
};

///当前银期所属交易中心
struct ICECurrTransferIdentityField
{
	///交易中心代码
	ICEDRIdentityIDType	IdentityID;
};

///禁止登录用户
struct ICELoginForbiddenUserField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
	///IP地址
	ICEIPAddressType	IPAddress;
};

///查询禁止登录用户
struct ICEQryLoginForbiddenUserField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///用户代码
	ICEUserIDType	UserID;
};

///UDP组播组信息
struct ICEMulticastGroupInfoField
{
	///组播组IP地址
	ICEIPAddressType	GroupIP;
	///组播组IP端口
	ICEIPPortType	GroupPort;
	///源地址
	ICEIPAddressType	SourceIP;
};

///资金账户基本准备金
struct ICETradingAccountReserveField
{
	///经纪公司代码
	ICEBrokerIDType	BrokerID;
	///投资者帐号
	ICEAccountIDType	AccountID;
	///基本准备金
	ICEMoneyType	Reserve;
	///币种代码
	ICECurrencyIDType	CurrencyID;
};

///DBF记录
struct ICEDBFRecordField
{
	///DBF命令类型
	ICEDBFComdTypeType	DBFComdType;
	///DBF时间类型
	ICEDBFComTimeType	DBFComTime;
	///DBF原始流水号类型
	ICEDBFComNoType	DBFOComNo;
	///DBF流水号类型
	ICEDBFComNoType	DBFComNo;
	///DBF字段类型
	ICEDBFFdNameType	DBFFdName1;
	///DBF字段内容类型
	ICEDBFFdContentType	DBFFdContent1;
	///DBF字段类型
	ICEDBFFdNameType	DBFFdName2;
	///DBF字段内容类型
	ICEDBFFdContentType	DBFFdContent2;
	///DBF字段类型
	ICEDBFFdNameType	DBFFdName3;
	///DBF字段内容类型
	ICEDBFFdContentType	DBFFdContent3;
	///DBF字段类型
	ICEDBFFdNameType	DBFFdName4;
	///DBF字段内容类型
	ICEDBFFdContentType	DBFFdContent4;
};

#endif